# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobufs/main.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14protobufs/main.proto\x12\x16zaber.motion.protobufs\"\x1a\n\x07Request\x12\x0f\n\x07request\x18\x01 \x01(\t\"\xb9\x01\n\x08Response\x12?\n\x08response\x18\x01 \x01(\x0e\x32-.zaber.motion.protobufs.Response.ResponseType\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"!\n\x0cResponseType\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\"\x16\n\x05\x45vent\x12\r\n\x05\x65vent\x18\x01 \x01(\t\"\x0e\n\x0c\x45mptyRequest\"\xdd\x01\n\x0c\x41xisIdentity\x12\x15\n\ris_peripheral\x18\x01 \x01(\x08\x12\x15\n\rperipheral_id\x18\x02 \x01(\x05\x12\x17\n\x0fperipheral_name\x18\x03 \x01(\t\x12@\n\taxis_type\x18\x04 \x01(\x0e\x32-.zaber.motion.protobufs.AxisIdentity.AxisType\x12\x13\n\x0bis_modified\x18\x05 \x01(\x08\"/\n\x08\x41xisType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\n\n\x06ROTARY\x10\x02\"\xcb\x01\n\x0e\x44\x65viceIdentity\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\naxis_count\x18\x04 \x01(\x05\x12\x41\n\x10\x66irmware_version\x18\x05 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\x12\x13\n\x0bis_modified\x18\x06 \x01(\x08\x12\x15\n\ris_integrated\x18\x07 \x01(\x08\">\n\x0f\x46irmwareVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05\x62uild\x18\x03 \x01(\x05\"\x8a\x01\n\x0c\x44\x65viceIOInfo\x12\x1d\n\x15number_analog_outputs\x18\x02 \x01(\x05\x12\x1c\n\x14number_analog_inputs\x18\x03 \x01(\x05\x12\x1e\n\x16number_digital_outputs\x18\x04 \x01(\x05\x12\x1d\n\x15number_digital_inputs\x18\x05 \x01(\x05\"*\n\x0bMeasurement\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\">\n\x14StreamAxisDefinition\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\x11\n\taxis_type\x18\x02 \x01(\x05\"<\n\x1aInvalidPacketExceptionData\x12\x0e\n\x06packet\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\">\n\"DeviceAddressConflictExceptionData\x12\x18\n\x10\x64\x65vice_addresses\x18\x01 \x03(\x05\"D\n MovementInterruptedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"J\n&StreamMovementInterruptedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"?\n\x1bMovementFailedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"E\n!StreamMovementFailedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"B\n\x1cStreamExecutionExceptionData\x12\x12\n\nerror_flag\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\"0\n\x1cInvalidResponseExceptionData\x12\x10\n\x08response\x18\x01 \x01(\t\"m\n\x1a\x43ommandFailedExceptionData\x12\x15\n\rresponse_data\x18\x01 \x01(\t\x12\x12\n\nreply_flag\x18\x05 \x01(\t\x12\x0e\n\x06status\x18\x06 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x07 \x01(\t\"9\n BinaryCommandFailedExceptionData\x12\x15\n\rresponse_data\x18\x01 \x01(\x05\"o\n\x1fSetPeripheralStateExceptionData\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\x10\n\x08settings\x18\x02 \x03(\t\x12\x14\n\x0cservo_tuning\x18\x03 \x01(\t\x12\x0f\n\x07storage\x18\x04 \x03(\t\"\xe1\x01\n\x1bSetDeviceStateExceptionData\x12L\n\x0bperipherals\x18\x02 \x03(\x0b\x32\x37.zaber.motion.protobufs.SetPeripheralStateExceptionData\x12\x10\n\x08settings\x18\x03 \x03(\t\x12\x16\n\x0estream_buffers\x18\x04 \x03(\t\x12\x10\n\x08triggers\x18\x05 \x03(\t\x12\x11\n\tip_config\x18\x06 \x01(\t\x12\x14\n\x0cservo_tuning\x18\x07 \x01(\t\x12\x0f\n\x07storage\x18\x08 \x03(\t\"V\n\x0bTestRequest\x12\x14\n\x0creturn_error\x18\x01 \x01(\x08\x12\x11\n\tdata_ping\x18\x02 \x01(\t\x12\x1e\n\x16return_error_with_data\x18\x03 \x01(\x08\"!\n\x0cTestResponse\x12\x11\n\tdata_pong\x18\x01 \x01(\t\"%\n\x10TestResponseLong\x12\x11\n\tdata_pong\x18\x01 \x03(\t\"\x19\n\tTestEvent\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"-\n\x1cToolsListSerialPortsResponse\x12\r\n\x05ports\x18\x01 \x03(\t\"-\n\x1cGetMessageRouterPipeResponse\x12\r\n\x05value\x18\x01 \x01(\t\"I\n\x18SetDeviceDbSourceRequest\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x18\n\x10url_or_file_path\x18\x02 \x01(\t\"G\n\x1aToggleDeviceDbStoreRequest\x12\x11\n\ttoggle_on\x18\x01 \x01(\x08\x12\x16\n\x0estore_location\x18\x02 \x01(\t\"\xa7\x02\n\x14OpenInterfaceRequest\x12=\n\x0einterface_type\x18\x01 \x01(\x0e\x32%.zaber.motion.protobufs.InterfaceType\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x11\n\tbaud_rate\x18\x03 \x01(\x05\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x11\n\ttransport\x18\x06 \x01(\x05\x12 \n\x18reject_routed_connection\x18\x07 \x01(\x08\x12\x10\n\x08\x63loud_id\x18\x08 \x01(\t\x12\x17\n\x0f\x63onnection_name\x18\t \x01(\t\x12\r\n\x05realm\x18\n \x01(\t\x12\r\n\x05token\x18\x0b \x01(\t\x12\x0b\n\x03\x61pi\x18\x0c \x01(\t\"-\n\x15OpenInterfaceResponse\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"-\n\x15\x43loseInterfaceRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"-\n\x15\x45mptyInterfaceRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\",\n\x1bGetInterfaceTimeoutResponse\x12\r\n\x05value\x18\x01 \x01(\x05\"C\n\x1aSetInterfaceTimeoutRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"4\n#GetInterfaceChecksumEnabledResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"N\n\"SetInterfaceChecksumEnabledRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\"E\n\x0fToStringRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\"\n\x10ToStringResponse\x12\x0e\n\x06to_str\x18\x01 \x01(\t\"\x83\x01\n\x15GenericCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x14\n\x0c\x63heck_errors\x18\x05 \x01(\x08\x12\x0f\n\x07timeout\x18\x06 \x01(\x05\"\xc8\x01\n\x16GenericCommandResponse\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"e\n GenericCommandResponseCollection\x12\x41\n\tresponses\x18\x02 \x03(\x0b\x32..zaber.motion.protobufs.GenericCommandResponse\"\xdc\x01\n\x14UnknownResponseEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"\x83\x01\n\nAlertEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"t\n\x11\x44isconnectedEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"D\n\x15\x44\x65viceRenumberRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x15\n\rfirst_address\x18\x02 \x01(\x05\"0\n\x16\x44\x65viceRenumberResponse\x12\x16\n\x0enumber_devices\x18\x01 \x01(\x05\"E\n\x13\x44\x65viceDetectRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x18\n\x10identify_devices\x18\x02 \x01(\x08\"\'\n\x14\x44\x65viceDetectResponse\x12\x0f\n\x07\x64\x65vices\x18\x01 \x03(\x05\"`\n\x11\x44\x65viceHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"n\n\x1a\x44\x65viceWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"\xf6\x01\n\x11\x44\x65viceMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\x12@\n\x04type\x18\x05 \x01(\x0e\x32\x32.zaber.motion.protobufs.DeviceMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\"7\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\x07\n\x03MIN\x10\x04\"`\n\x11\x44\x65viceStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"=\n\x15\x44\x65viceIdentifyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"C\n\x12\x44\x65viceOnAllRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x02 \x01(\x08\"/\n\x13\x44\x65viceOnAllResponse\x12\x18\n\x10\x64\x65vice_addresses\x18\x01 \x03(\x05\"@\n\x18\x44\x65viceGetIdentityRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"U\n\x19\x44\x65viceGetIdentityResponse\x12\x38\n\x08identity\x18\x01 \x01(\x0b\x32&.zaber.motion.protobufs.DeviceIdentity\"D\n\x1c\x44\x65viceGetIsIdentifiedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"6\n\x1d\x44\x65viceGetIsIdentifiedResponse\x12\x15\n\ris_identified\x18\x01 \x01(\x08\"R\n\x1c\x44\x65viceGetAxisIdentityRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"W\n\x1d\x44\x65viceGetAxisIdentityResponse\x12\x36\n\x08identity\x18\x01 \x01(\x0b\x32$.zaber.motion.protobufs.AxisIdentity\"I\n\x13\x44\x65viceIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\'\n\x14\x44\x65viceIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"]\n\x18\x44\x65viceGetWarningsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05\x63lear\x18\x04 \x01(\x08\"*\n\x19\x44\x65viceGetWarningsResponse\x12\r\n\x05\x66lags\x18\x01 \x03(\t\"Z\n\x1c\x44\x65viceGetAllDigitalIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\"/\n\x1d\x44\x65viceGetAllDigitalIOResponse\x12\x0e\n\x06values\x18\x01 \x03(\x08\"Y\n\x1b\x44\x65viceGetAllAnalogIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\".\n\x1c\x44\x65viceGetAllAnalogIOResponse\x12\x0e\n\x06values\x18\x01 \x03(\x01\"o\n\x19\x44\x65viceGetDigitalIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"+\n\x1a\x44\x65viceGetDigitalIOResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"n\n\x18\x44\x65viceGetAnalogIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"*\n\x19\x44\x65viceGetAnalogIOResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"Y\n!DeviceSetAllDigitalOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x08\"X\n DeviceSetAllAnalogOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x01\"l\n\x1d\x44\x65viceSetDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x08\"k\n\x1c\x44\x65viceSetAnalogOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x01\"F\n\x1e\x44\x65viceGetIOChannelsInfoRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"6\n\x13SetLogOutputRequest\x12\x0c\n\x04mode\x18\x01 \x01(\x05\x12\x11\n\tfile_path\x18\x02 \x01(\t\"l\n\x17\x44\x65viceGetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\")\n\x18\x44\x65viceGetSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\",\n\x1b\x44\x65viceGetSettingStrResponse\x12\r\n\x05value\x18\x01 \x01(\t\"\x94\x01\n\x1b\x44\x65viceConvertSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\r\n\x05value\x18\x06 \x01(\x01\x12\x13\n\x0b\x66rom_native\x18\x07 \x01(\x08\"-\n\x1c\x44\x65viceConvertSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"{\n\x17\x44\x65viceSetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"p\n\x1a\x44\x65viceSetSettingStrRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\"\x9e\x01\n\x15PrepareCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x18\n\x10\x63ommand_template\x18\x04 \x01(\t\x12\x37\n\nparameters\x18\x05 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\")\n\x16PrepareCommandResponse\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\"G\n\x11\x44\x65viceParkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"+\n\x16\x44\x65viceIsParkedResponse\x12\x11\n\tis_parked\x18\x01 \x01(\x08\"f\n\x15LockstepEnableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x04 \x03(\x05\"r\n\x16LockstepDisableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"o\n\x13LockstepStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"o\n\x13LockstepHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"\x87\x02\n\x13LockstepMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\x12\x42\n\x04type\x18\x05 \x01(\x0e\x32\x34.zaber.motion.protobufs.LockstepMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x08 \x01(\t\"7\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\x07\n\x03MIN\x10\x04\"}\n\x1cLockstepWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"X\n\x15LockstepIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\")\n\x16LockstepIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"Y\n\x16LockstepGetAxesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\"N\n\x0cLockstepAxes\x12\x0e\n\x06\x61xis_1\x18\x01 \x01(\x05\x12\x0e\n\x06\x61xis_2\x18\x02 \x01(\x05\x12\x0e\n\x06\x61xis_3\x18\x03 \x01(\x05\x12\x0e\n\x06\x61xis_4\x18\x04 \x01(\x05\"M\n\x17LockstepGetAxesResponse\x12\x32\n\x04\x61xes\x18\x01 \x01(\x0b\x32$.zaber.motion.protobufs.LockstepAxes\"`\n\x1dLockstepGetAxisNumbersRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\".\n\x1eLockstepGetAxisNumbersResponse\x12\x0c\n\x04\x61xes\x18\x01 \x03(\x05\"i\n\x18LockstepGetTwistsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"+\n\x19LockstepGetTwistsResponse\x12\x0e\n\x06twists\x18\x01 \x03(\x01\"j\n\x19LockstepGetOffsetsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"-\n\x1aLockstepGetOffsetsResponse\x12\x0f\n\x07offsets\x18\x01 \x03(\x01\"[\n\x18LockstepIsEnabledRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\"/\n\x19LockstepIsEnabledResponse\x12\x12\n\nis_enabled\x18\x01 \x01(\x08\"Z\n\x17LockstepToStringRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\"*\n\x18LockstepToStringResponse\x12\x0e\n\x06to_str\x18\x01 \x01(\t\"d\n\x1dOscilloscopeAddChannelRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\"H\n OscilloscopeClearChannelsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"S\n\x1cOscilloscopeStartStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\r\n\x05start\x18\x03 \x01(\x08\"?\n\x17OscilloscopeReadRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\",\n\x18OscilloscopeReadResponse\x12\x10\n\x08\x64\x61ta_ids\x18\x01 \x03(\x05\"S\n\x1aOscilloscopeDataIdentifier\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61ta_id\x18\x03 \x01(\x05\"E\n\x1dOscilloscopeCaptureProperties\x12\x0f\n\x07setting\x18\x01 \x01(\t\x12\x13\n\x0b\x61xis_number\x18\x02 \x01(\x05\"r\n%OscilloscopeDataGetPropertiesResponse\x12I\n\nproperties\x18\x01 \x01(\x0b\x32\x35.zaber.motion.protobufs.OscilloscopeCaptureProperties\"m\n&OscilloscopeDataGetSavedSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61ta_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"8\n\'OscilloscopeDataGetSavedSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"z\n$OscilloscopeDataGetSampleTimeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61ta_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x05\"h\n!OscilloscopeDataGetSamplesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61ta_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"2\n\"OscilloscopeDataGetSamplesResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"_\n\x16StreamSetupLiveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x04 \x03(\x05\"\x96\x01\n\x1fStreamSetupLiveCompositeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12:\n\x04\x61xes\x18\x04 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"w\n\x17StreamSetupStoreRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x05 \x03(\x05\"\xae\x01\n StreamSetupStoreCompositeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12:\n\x04\x61xes\x18\x05 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"\x8a\x01\n$StreamSetupStoreArbitraryAxesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12\x12\n\naxes_count\x18\x05 \x01(\x05\"c\n\x11StreamCallRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\"\xf8\x01\n\x11StreamLineRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12<\n\x04type\x18\x04 \x01(\x0e\x32..zaber.motion.protobufs.StreamLineRequest.Type\x12\x35\n\x08\x65ndpoint\x18\x05 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\x06 \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\xb1\x03\n\x10StreamArcRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12;\n\x04type\x18\x04 \x01(\x0e\x32-.zaber.motion.protobufs.StreamArcRequest.Type\x12\x1a\n\x12rotation_direction\x18\x05 \x01(\x05\x12\x35\n\x08\x63\x65nter_x\x18\x06 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x35\n\x08\x63\x65nter_y\x18\x07 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x32\n\x05\x65nd_x\x18\x08 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x32\n\x05\x65nd_y\x18\t \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\n \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\xcf\x02\n\x13StreamCircleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12>\n\x04type\x18\x04 \x01(\x0e\x32\x30.zaber.motion.protobufs.StreamCircleRequest.Type\x12\x1a\n\x12rotation_direction\x18\x05 \x01(\x05\x12\x35\n\x08\x63\x65nter_x\x18\x06 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x35\n\x08\x63\x65nter_y\x18\x07 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\x08 \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\x7f\n\x1dStreamWaitDigitalInputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x08\"\x91\x01\n\x1cStreamWaitAnalogInputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\x11\n\tcondition\x18\x05 \x01(\t\x12\r\n\x05value\x18\x06 \x01(\x01\"\x7f\n\x1dStreamSetDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x08\"~\n\x1cStreamSetAnalogOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x01\"s\n StreamToggleDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"l\n!StreamSetAllDigitalOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x08\"k\n StreamSetAllAnalogOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x01\"h\n\x11StreamWaitRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04time\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"s\n\x1aStreamWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"L\n\x11StreamCorkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"N\n\x13StreamUncorkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"N\n\x13StreamIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"\'\n\x14StreamIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"O\n\x14StreamGetAxesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"S\n\x15StreamGetAxesResponse\x12:\n\x04\x61xes\x18\x01 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"O\n\x14StreamGetModeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"%\n\x15StreamGetModeResponse\x12\x0c\n\x04mode\x18\x01 \x01(\x05\"a\n\x18StreamGetMaxSpeedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\".\n\x19StreamGetMaxSpeedResponse\x12\x11\n\tmax_speed\x18\x01 \x01(\x01\"t\n\x18StreamSetMaxSpeedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x11\n\tmax_speed\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"r\n)StreamGetMaxTangentialAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"Q\n*StreamGetMaxTangentialAccelerationResponse\x12#\n\x1bmax_tangential_acceleration\x18\x01 \x01(\x01\"\x97\x01\n)StreamSetMaxTangentialAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12#\n\x1bmax_tangential_acceleration\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"s\n*StreamGetMaxCentripetalAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"S\n+StreamGetMaxCentripetalAccelerationResponse\x12$\n\x1cmax_centripetal_acceleration\x18\x01 \x01(\x01\"\x99\x01\n*StreamSetMaxCentripetalAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12$\n\x1cmax_centripetal_acceleration\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"P\n\x15StreamToStringRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"(\n\x16StreamToStringResponse\x12\x0e\n\x06to_str\x18\x01 \x01(\t\"O\n\x14StreamDisableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"X\n\x1dStreamBufferGetContentRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tbuffer_id\x18\x03 \x01(\x05\"6\n\x1eStreamBufferGetContentResponse\x12\x14\n\x0c\x62uffer_lines\x18\x01 \x03(\t\"S\n\x18StreamBufferEraseRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tbuffer_id\x18\x03 \x01(\x05\"g\n\x1bStreamGenericCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\"j\n StreamGenericCommandBatchRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\r\n\x05\x62\x61tch\x18\x04 \x03(\t\"c\n\x14\x42inaryReplyOnlyEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\"\xbb\x01\n\x1aOpenBinaryInterfaceRequest\x12=\n\x0einterface_type\x18\x01 \x01(\x0e\x32%.zaber.motion.protobufs.InterfaceType\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x11\n\tbaud_rate\x18\x03 \x01(\x05\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x17\n\x0fuse_message_ids\x18\x06 \x01(\x08\"i\n\x1aUnknownBinaryResponseEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\"\x82\x01\n\x14GenericBinaryRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\x12\x14\n\x0c\x63heck_errors\x18\x05 \x01(\x08\x12\x0f\n\x07timeout\x18\x06 \x01(\x01\"F\n\rBinaryMessage\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x05\"R\n\x17\x42inaryMessageCollection\x12\x37\n\x08messages\x18\x02 \x03(\x0b\x32%.zaber.motion.protobufs.BinaryMessage\"3\n\x1b\x42inaryDeviceRenumberRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"6\n\x1c\x42inaryDeviceRenumberResponse\x12\x16\n\x0enumber_devices\x18\x01 \x01(\x05\"C\n\x1b\x42inaryDeviceIdentifyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"\xd9\x02\n\x14\x42inaryDeviceIdentity\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x41\n\x10\x66irmware_version\x18\x05 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\x12\x15\n\ris_peripheral\x18\x06 \x01(\x08\x12\x15\n\rperipheral_id\x18\x07 \x01(\x05\x12\x17\n\x0fperipheral_name\x18\x08 \x01(\t\x12L\n\x0b\x64\x65vice_type\x18\t \x01(\x0e\x32\x37.zaber.motion.protobufs.BinaryDeviceIdentity.DeviceType\"1\n\nDeviceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\n\n\x06ROTARY\x10\x02\"F\n\x1e\x42inaryDeviceGetIdentityRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"a\n\x1f\x42inaryDeviceGetIdentityResponse\x12>\n\x08identity\x18\x01 \x01(\x0b\x32,.zaber.motion.protobufs.BinaryDeviceIdentity\"J\n\"BinaryDeviceGetIsIdentifiedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"<\n#BinaryDeviceGetIsIdentifiedResponse\x12\x15\n\ris_identified\x18\x01 \x01(\x08\"\x99\x01\n\x1d\x42inaryGenericWithUnitsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x01\x12\x11\n\tfrom_unit\x18\x05 \x01(\t\x12\x0f\n\x07to_unit\x18\x06 \x01(\t\x12\x0f\n\x07timeout\x18\x07 \x01(\x01\".\n\x1e\x42inaryGenericWithUnitsResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x01\"^\n\x17\x42inaryDeviceHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\",\n\x1c\x42inaryDeviceMovementResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x01\"\xda\x01\n\x17\x42inaryDeviceMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x46\n\x04type\x18\x04 \x01(\x0e\x32\x38.zaber.motion.protobufs.BinaryDeviceMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"%\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\"^\n\x17\x42inaryDeviceStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\"H\n BinaryDeviceWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"A\n\x19\x42inaryDeviceIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"-\n\x1a\x42inaryDeviceIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"K\n\x19\x42inaryDeviceDetectRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x18\n\x10identify_devices\x18\x02 \x01(\x08\"-\n\x1a\x42inaryDeviceDetectResponse\x12\x0f\n\x07\x64\x65vices\x18\x01 \x03(\x05\"d\n\x1d\x42inaryDeviceGetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07setting\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"/\n\x1e\x42inaryDeviceGetSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"s\n\x1d\x42inaryDeviceSetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07setting\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"?\n\x17\x42inaryDeviceParkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"-\n\x18\x42inaryDeviceParkResponse\x12\x11\n\tis_parked\x18\x01 \x01(\x08\"2\n\x1a\x43ustomInterfaceReadRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\".\n\x1b\x43ustomInterfaceReadResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"D\n\x1b\x43ustomInterfaceWriteRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"3\n\x1b\x43ustomInterfaceOpenResponse\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\"J\n\x1b\x43ustomInterfaceCloseRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"E\n\x0fGetStateRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"!\n\x10GetStateResponse\x12\r\n\x05state\x18\x01 \x01(\t\"l\n\x12\x43\x61nSetStateRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05state\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_only\x18\x05 \x01(\x08\"=\n\x17\x43\x61nSetStateAxisResponse\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"v\n\x19\x43\x61nSetStateDeviceResponse\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12J\n\x11peripheral_errors\x18\x03 \x03(\x0b\x32/.zaber.motion.protobufs.CanSetStateAxisResponse\"i\n\x0fSetStateRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05state\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_only\x18\x05 \x01(\x08\"Z\n\x12ServoTuningRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\"/\n\x10ServoTuningParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\"V\n\x0cParamsetInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x38\n\x06params\x18\x02 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"\x9e\x01\n\x15SetServoTuningRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12?\n\rtuning_params\x18\x05 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"H\n\x12GetStartupParamset\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"#\n\x0fStartupParamset\x12\x10\n\x08paramset\x18\x01 \x01(\x05\"n\n\x0cLoadParamset\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x13\n\x0bto_paramset\x18\x04 \x01(\x05\x12\x15\n\rfrom_paramset\x18\x05 \x01(\x05\"\x8d\x01\n\x18SetServoTuningPIDRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12\t\n\x01p\x18\x05 \x01(\x01\x12\t\n\x01i\x18\x06 \x01(\x01\x12\t\n\x01\x64\x18\x07 \x01(\x01\x12\n\n\x02\x66\x63\x18\x08 \x01(\x01\"W\n\tPidTuning\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\t\n\x01p\x18\x03 \x01(\x01\x12\t\n\x01i\x18\x04 \x01(\x01\x12\t\n\x01\x64\x18\x05 \x01(\x01\x12\n\n\x02\x66\x63\x18\x06 \x01(\x01\"U\n\x1fGetSimpleTuningParamListRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\xc2\x01\n\x0fSetSimpleTuning\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12\x15\n\rcarriage_mass\x18\x05 \x01(\x01\x12\x11\n\tload_mass\x18\x06 \x01(\x01\x12?\n\rtuning_params\x18\x07 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"Z\n\x11SimpleTuningParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmin_label\x18\x02 \x01(\t\x12\x11\n\tmax_label\x18\x03 \x01(\t\x12\x11\n\tdata_type\x18\x04 \x01(\t\"R\n\x15SimpleTuningParamList\x12\x39\n\x06params\x18\x01 \x03(\x0b\x32).zaber.motion.protobufs.SimpleTuningParam\"\x95\x01\n\x17TranslatorCreateRequest\x12@\n\ndefinition\x18\x01 \x01(\x0b\x32,.zaber.motion.protobufs.TranslatorDefinition\x12\x38\n\x06\x63onfig\x18\x02 \x01(\x0b\x32(.zaber.motion.protobufs.TranslatorConfig\"1\n\x18TranslatorCreateResponse\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\"O\n\x18TranslatorAxisDefinition\x12\x15\n\rperipheral_id\x18\x01 \x01(\x05\x12\x1c\n\x14microstep_resolution\x18\x02 \x01(\x05\"\xa1\x01\n\x14TranslatorDefinition\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12>\n\x04\x61xes\x18\x02 \x03(\x0b\x32\x30.zaber.motion.protobufs.TranslatorAxisDefinition\x12\x36\n\tmax_speed\x18\x03 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\"\xac\x01\n\x10TranslatorConfig\x12\x44\n\raxis_mappings\x18\x01 \x03(\x0b\x32-.zaber.motion.protobufs.TranslatorAxisMapping\x12R\n\x14\x61xis_transformations\x18\x02 \x03(\x0b\x32\x34.zaber.motion.protobufs.TranslatorAxisTransformation\"@\n\x15TranslatorAxisMapping\x12\x13\n\x0b\x61xis_letter\x18\x01 \x01(\t\x12\x12\n\naxis_index\x18\x02 \x01(\x05\"~\n\x1cTranslatorAxisTransformation\x12\x13\n\x0b\x61xis_letter\x18\x01 \x01(\t\x12\x0f\n\x07scaling\x18\x02 \x01(\x01\x12\x38\n\x0btranslation\x18\x03 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\"B\n\x1aTranslatorTranslateRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\r\n\x05\x62lock\x18\x02 \x01(\t\"I\n\x10TranslateMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x12\n\nfrom_block\x18\x02 \x01(\x05\x12\x10\n\x08to_block\x18\x03 \x01(\x05\"k\n\x1bTranslatorTranslateResponse\x12\x10\n\x08\x63ommands\x18\x01 \x03(\t\x12:\n\x08warnings\x18\x02 \x03(\x0b\x32(.zaber.motion.protobufs.TranslateMessage\"@\n\x18GCodeSyntaxExceptionData\x12\x12\n\nfrom_block\x18\x01 \x01(\x05\x12\x10\n\x08to_block\x18\x02 \x01(\x05\"C\n\x1bGCodeExecutionExceptionData\x12\x12\n\nfrom_block\x18\x01 \x01(\x05\x12\x10\n\x08to_block\x18\x02 \x01(\x05\"L\n\x1aTranslatorFlushLiveRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x02 \x01(\x08\"+\n\x17TranslatorFlushResponse\x12\x10\n\x08\x63ommands\x18\x01 \x03(\t\"\x90\x01\n\x1bTranslatorCreateLiveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x38\n\x06\x63onfig\x18\x04 \x01(\x0b\x32(.zaber.motion.protobufs.TranslatorConfig\"/\n\x16TranslatorEmptyRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\"^\n TranslatorSetTraverseRateRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x15\n\rtraverse_rate\x18\x02 \x01(\x01\x12\x0c\n\x04unit\x18\x03 \x01(\t\"g\n TranslatorSetAxisPositionRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x02 \x01(\t\x12\x10\n\x08position\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\"U\n TranslatorGetAxisPositionRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\"2\n!TranslatorGetAxisPositionResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"n\n\x1eTranslatorGetAxisOffsetRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x19\n\x11\x63oordinate_system\x18\x02 \x01(\t\x12\x0c\n\x04\x61xis\x18\x03 \x01(\t\x12\x0c\n\x04unit\x18\x04 \x01(\t\"=\n,TranslatorGetCurrentCoordinateSystemResponse\x12\r\n\x05value\x18\x01 \x01(\t\"R\n$TranslatorSetFeedRateOverrideRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x13\n\x0b\x63oefficient\x18\x02 \x01(\x01*-\n\x0bMessageType\x12\t\n\x05REPLY\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x41LERT\x10\x02*\xcb\x07\n\x06\x45rrors\x12\x13\n\x0fREQUEST_TIMEOUT\x10\x00\x12\x15\n\x11\x43ONNECTION_CLOSED\x10\x01\x12\x14\n\x10INVALID_ARGUMENT\x10\x02\x12\x16\n\x12OUT_OF_REQUEST_IDS\x10\x03\x12\x12\n\x0eINVALID_PACKET\x10\x04\x12\x15\n\x11\x43ONNECTION_FAILED\x10\x05\x12\x13\n\x0fUNKNOWN_REQUEST\x10\x06\x12\x12\n\x0e\x43OMMAND_FAILED\x10\x07\x12\x14\n\x10\x44\x45VICE_DB_FAILED\x10\x08\x12\x10\n\x0cINVALID_DATA\x10\t\x12\x19\n\x15\x44\x45VICE_NOT_IDENTIFIED\x10\n\x12\x15\n\x11\x43ONVERSION_FAILED\x10\x0b\x12\x1b\n\x17\x44\x45VICE_ADDRESS_CONFLICT\x10\x0c\x12\x13\n\x0fNO_DEVICE_FOUND\x10\r\x12\x18\n\x14MOVEMENT_INTERRUPTED\x10\x0e\x12\x13\n\x0fMOVEMENT_FAILED\x10\x0f\x12\r\n\tIO_FAILED\x10\x10\x12\x14\n\x10INVALID_RESPONSE\x10\x11\x12\x11\n\rNOT_SUPPORTED\x10\x12\x12\x11\n\rDEVICE_FAILED\x10\x13\x12\r\n\tOS_FAILED\x10\x14\x12\x12\n\x0eINTERNAL_ERROR\x10\x16\x12\x19\n\x15\x42INARY_COMMAND_FAILED\x10\x18\x12\x15\n\x11\x43OMMAND_PREEMPTED\x10\x19\x12\x18\n\x14LOCKSTEP_NOT_ENABLED\x10\x1a\x12\x14\n\x10LOCKSTEP_ENABLED\x10\x1b\x12\x1b\n\x17IO_CHANNEL_OUT_OF_RANGE\x10\x1c\x12\x15\n\x11SETTING_NOT_FOUND\x10\x1d\x12\x0f\n\x0bSTREAM_MODE\x10\x1e\x12\x14\n\x10STREAM_EXECUTION\x10\x1f\x12\x1a\n\x16STREAM_MOVEMENT_FAILED\x10 \x12\x17\n\x13STREAM_SETUP_FAILED\x10!\x12\x0f\n\x0b\x44\x45VICE_BUSY\x10\"\x12\x1f\n\x1bSTREAM_MOVEMENT_INTERRUPTED\x10#\x12\x16\n\x12INVALID_PARK_STATE\x10$\x12\x14\n\x10SERIAL_PORT_BUSY\x10%\x12\x1a\n\x16TRANSPORT_ALREADY_USED\x10&\x12\x1f\n\x1bSET_PERIPHERAL_STATE_FAILED\x10\'\x12\x1b\n\x17SET_DEVICE_STATE_FAILED\x10(\x12\x11\n\rG_CODE_SYNTAX\x10)\x12\x14\n\x10G_CODE_EXECUTION\x10*\x12\x15\n\x11INVALID_OPERATION\x10+*Q\n\rInterfaceType\x12\x0f\n\x0bSERIAL_PORT\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\n\n\x06\x43USTOM\x10\x02\x12\x07\n\x03IOT\x10\x03\x12\x11\n\rNETWORK_SHARE\x10\x04\x42$Z\"./protobufs;zaber_motion_protobufsb\x06proto3')

_MESSAGETYPE = DESCRIPTOR.enum_types_by_name['MessageType']
MessageType = enum_type_wrapper.EnumTypeWrapper(_MESSAGETYPE)
_ERRORS = DESCRIPTOR.enum_types_by_name['Errors']
Errors = enum_type_wrapper.EnumTypeWrapper(_ERRORS)
_INTERFACETYPE = DESCRIPTOR.enum_types_by_name['InterfaceType']
InterfaceType = enum_type_wrapper.EnumTypeWrapper(_INTERFACETYPE)
REPLY = 0
INFO = 1
ALERT = 2
REQUEST_TIMEOUT = 0
CONNECTION_CLOSED = 1
INVALID_ARGUMENT = 2
OUT_OF_REQUEST_IDS = 3
INVALID_PACKET = 4
CONNECTION_FAILED = 5
UNKNOWN_REQUEST = 6
COMMAND_FAILED = 7
DEVICE_DB_FAILED = 8
INVALID_DATA = 9
DEVICE_NOT_IDENTIFIED = 10
CONVERSION_FAILED = 11
DEVICE_ADDRESS_CONFLICT = 12
NO_DEVICE_FOUND = 13
MOVEMENT_INTERRUPTED = 14
MOVEMENT_FAILED = 15
IO_FAILED = 16
INVALID_RESPONSE = 17
NOT_SUPPORTED = 18
DEVICE_FAILED = 19
OS_FAILED = 20
INTERNAL_ERROR = 22
BINARY_COMMAND_FAILED = 24
COMMAND_PREEMPTED = 25
LOCKSTEP_NOT_ENABLED = 26
LOCKSTEP_ENABLED = 27
IO_CHANNEL_OUT_OF_RANGE = 28
SETTING_NOT_FOUND = 29
STREAM_MODE = 30
STREAM_EXECUTION = 31
STREAM_MOVEMENT_FAILED = 32
STREAM_SETUP_FAILED = 33
DEVICE_BUSY = 34
STREAM_MOVEMENT_INTERRUPTED = 35
INVALID_PARK_STATE = 36
SERIAL_PORT_BUSY = 37
TRANSPORT_ALREADY_USED = 38
SET_PERIPHERAL_STATE_FAILED = 39
SET_DEVICE_STATE_FAILED = 40
G_CODE_SYNTAX = 41
G_CODE_EXECUTION = 42
INVALID_OPERATION = 43
SERIAL_PORT = 0
TCP = 1
CUSTOM = 2
IOT = 3
NETWORK_SHARE = 4


_REQUEST = DESCRIPTOR.message_types_by_name['Request']
_RESPONSE = DESCRIPTOR.message_types_by_name['Response']
_EVENT = DESCRIPTOR.message_types_by_name['Event']
_EMPTYREQUEST = DESCRIPTOR.message_types_by_name['EmptyRequest']
_AXISIDENTITY = DESCRIPTOR.message_types_by_name['AxisIdentity']
_DEVICEIDENTITY = DESCRIPTOR.message_types_by_name['DeviceIdentity']
_FIRMWAREVERSION = DESCRIPTOR.message_types_by_name['FirmwareVersion']
_DEVICEIOINFO = DESCRIPTOR.message_types_by_name['DeviceIOInfo']
_MEASUREMENT = DESCRIPTOR.message_types_by_name['Measurement']
_STREAMAXISDEFINITION = DESCRIPTOR.message_types_by_name['StreamAxisDefinition']
_INVALIDPACKETEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['InvalidPacketExceptionData']
_DEVICEADDRESSCONFLICTEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['DeviceAddressConflictExceptionData']
_MOVEMENTINTERRUPTEDEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['MovementInterruptedExceptionData']
_STREAMMOVEMENTINTERRUPTEDEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['StreamMovementInterruptedExceptionData']
_MOVEMENTFAILEDEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['MovementFailedExceptionData']
_STREAMMOVEMENTFAILEDEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['StreamMovementFailedExceptionData']
_STREAMEXECUTIONEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['StreamExecutionExceptionData']
_INVALIDRESPONSEEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['InvalidResponseExceptionData']
_COMMANDFAILEDEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['CommandFailedExceptionData']
_BINARYCOMMANDFAILEDEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['BinaryCommandFailedExceptionData']
_SETPERIPHERALSTATEEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['SetPeripheralStateExceptionData']
_SETDEVICESTATEEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['SetDeviceStateExceptionData']
_TESTREQUEST = DESCRIPTOR.message_types_by_name['TestRequest']
_TESTRESPONSE = DESCRIPTOR.message_types_by_name['TestResponse']
_TESTRESPONSELONG = DESCRIPTOR.message_types_by_name['TestResponseLong']
_TESTEVENT = DESCRIPTOR.message_types_by_name['TestEvent']
_TOOLSLISTSERIALPORTSRESPONSE = DESCRIPTOR.message_types_by_name['ToolsListSerialPortsResponse']
_GETMESSAGEROUTERPIPERESPONSE = DESCRIPTOR.message_types_by_name['GetMessageRouterPipeResponse']
_SETDEVICEDBSOURCEREQUEST = DESCRIPTOR.message_types_by_name['SetDeviceDbSourceRequest']
_TOGGLEDEVICEDBSTOREREQUEST = DESCRIPTOR.message_types_by_name['ToggleDeviceDbStoreRequest']
_OPENINTERFACEREQUEST = DESCRIPTOR.message_types_by_name['OpenInterfaceRequest']
_OPENINTERFACERESPONSE = DESCRIPTOR.message_types_by_name['OpenInterfaceResponse']
_CLOSEINTERFACEREQUEST = DESCRIPTOR.message_types_by_name['CloseInterfaceRequest']
_EMPTYINTERFACEREQUEST = DESCRIPTOR.message_types_by_name['EmptyInterfaceRequest']
_GETINTERFACETIMEOUTRESPONSE = DESCRIPTOR.message_types_by_name['GetInterfaceTimeoutResponse']
_SETINTERFACETIMEOUTREQUEST = DESCRIPTOR.message_types_by_name['SetInterfaceTimeoutRequest']
_GETINTERFACECHECKSUMENABLEDRESPONSE = DESCRIPTOR.message_types_by_name['GetInterfaceChecksumEnabledResponse']
_SETINTERFACECHECKSUMENABLEDREQUEST = DESCRIPTOR.message_types_by_name['SetInterfaceChecksumEnabledRequest']
_TOSTRINGREQUEST = DESCRIPTOR.message_types_by_name['ToStringRequest']
_TOSTRINGRESPONSE = DESCRIPTOR.message_types_by_name['ToStringResponse']
_GENERICCOMMANDREQUEST = DESCRIPTOR.message_types_by_name['GenericCommandRequest']
_GENERICCOMMANDRESPONSE = DESCRIPTOR.message_types_by_name['GenericCommandResponse']
_GENERICCOMMANDRESPONSECOLLECTION = DESCRIPTOR.message_types_by_name['GenericCommandResponseCollection']
_UNKNOWNRESPONSEEVENT = DESCRIPTOR.message_types_by_name['UnknownResponseEvent']
_ALERTEVENT = DESCRIPTOR.message_types_by_name['AlertEvent']
_DISCONNECTEDEVENT = DESCRIPTOR.message_types_by_name['DisconnectedEvent']
_DEVICERENUMBERREQUEST = DESCRIPTOR.message_types_by_name['DeviceRenumberRequest']
_DEVICERENUMBERRESPONSE = DESCRIPTOR.message_types_by_name['DeviceRenumberResponse']
_DEVICEDETECTREQUEST = DESCRIPTOR.message_types_by_name['DeviceDetectRequest']
_DEVICEDETECTRESPONSE = DESCRIPTOR.message_types_by_name['DeviceDetectResponse']
_DEVICEHOMEREQUEST = DESCRIPTOR.message_types_by_name['DeviceHomeRequest']
_DEVICEWAITUNTILIDLEREQUEST = DESCRIPTOR.message_types_by_name['DeviceWaitUntilIdleRequest']
_DEVICEMOVEREQUEST = DESCRIPTOR.message_types_by_name['DeviceMoveRequest']
_DEVICESTOPREQUEST = DESCRIPTOR.message_types_by_name['DeviceStopRequest']
_DEVICEIDENTIFYREQUEST = DESCRIPTOR.message_types_by_name['DeviceIdentifyRequest']
_DEVICEONALLREQUEST = DESCRIPTOR.message_types_by_name['DeviceOnAllRequest']
_DEVICEONALLRESPONSE = DESCRIPTOR.message_types_by_name['DeviceOnAllResponse']
_DEVICEGETIDENTITYREQUEST = DESCRIPTOR.message_types_by_name['DeviceGetIdentityRequest']
_DEVICEGETIDENTITYRESPONSE = DESCRIPTOR.message_types_by_name['DeviceGetIdentityResponse']
_DEVICEGETISIDENTIFIEDREQUEST = DESCRIPTOR.message_types_by_name['DeviceGetIsIdentifiedRequest']
_DEVICEGETISIDENTIFIEDRESPONSE = DESCRIPTOR.message_types_by_name['DeviceGetIsIdentifiedResponse']
_DEVICEGETAXISIDENTITYREQUEST = DESCRIPTOR.message_types_by_name['DeviceGetAxisIdentityRequest']
_DEVICEGETAXISIDENTITYRESPONSE = DESCRIPTOR.message_types_by_name['DeviceGetAxisIdentityResponse']
_DEVICEISBUSYREQUEST = DESCRIPTOR.message_types_by_name['DeviceIsBusyRequest']
_DEVICEISBUSYRESPONSE = DESCRIPTOR.message_types_by_name['DeviceIsBusyResponse']
_DEVICEGETWARNINGSREQUEST = DESCRIPTOR.message_types_by_name['DeviceGetWarningsRequest']
_DEVICEGETWARNINGSRESPONSE = DESCRIPTOR.message_types_by_name['DeviceGetWarningsResponse']
_DEVICEGETALLDIGITALIOREQUEST = DESCRIPTOR.message_types_by_name['DeviceGetAllDigitalIORequest']
_DEVICEGETALLDIGITALIORESPONSE = DESCRIPTOR.message_types_by_name['DeviceGetAllDigitalIOResponse']
_DEVICEGETALLANALOGIOREQUEST = DESCRIPTOR.message_types_by_name['DeviceGetAllAnalogIORequest']
_DEVICEGETALLANALOGIORESPONSE = DESCRIPTOR.message_types_by_name['DeviceGetAllAnalogIOResponse']
_DEVICEGETDIGITALIOREQUEST = DESCRIPTOR.message_types_by_name['DeviceGetDigitalIORequest']
_DEVICEGETDIGITALIORESPONSE = DESCRIPTOR.message_types_by_name['DeviceGetDigitalIOResponse']
_DEVICEGETANALOGIOREQUEST = DESCRIPTOR.message_types_by_name['DeviceGetAnalogIORequest']
_DEVICEGETANALOGIORESPONSE = DESCRIPTOR.message_types_by_name['DeviceGetAnalogIOResponse']
_DEVICESETALLDIGITALOUTPUTSREQUEST = DESCRIPTOR.message_types_by_name['DeviceSetAllDigitalOutputsRequest']
_DEVICESETALLANALOGOUTPUTSREQUEST = DESCRIPTOR.message_types_by_name['DeviceSetAllAnalogOutputsRequest']
_DEVICESETDIGITALOUTPUTREQUEST = DESCRIPTOR.message_types_by_name['DeviceSetDigitalOutputRequest']
_DEVICESETANALOGOUTPUTREQUEST = DESCRIPTOR.message_types_by_name['DeviceSetAnalogOutputRequest']
_DEVICEGETIOCHANNELSINFOREQUEST = DESCRIPTOR.message_types_by_name['DeviceGetIOChannelsInfoRequest']
_SETLOGOUTPUTREQUEST = DESCRIPTOR.message_types_by_name['SetLogOutputRequest']
_DEVICEGETSETTINGREQUEST = DESCRIPTOR.message_types_by_name['DeviceGetSettingRequest']
_DEVICEGETSETTINGRESPONSE = DESCRIPTOR.message_types_by_name['DeviceGetSettingResponse']
_DEVICEGETSETTINGSTRRESPONSE = DESCRIPTOR.message_types_by_name['DeviceGetSettingStrResponse']
_DEVICECONVERTSETTINGREQUEST = DESCRIPTOR.message_types_by_name['DeviceConvertSettingRequest']
_DEVICECONVERTSETTINGRESPONSE = DESCRIPTOR.message_types_by_name['DeviceConvertSettingResponse']
_DEVICESETSETTINGREQUEST = DESCRIPTOR.message_types_by_name['DeviceSetSettingRequest']
_DEVICESETSETTINGSTRREQUEST = DESCRIPTOR.message_types_by_name['DeviceSetSettingStrRequest']
_PREPARECOMMANDREQUEST = DESCRIPTOR.message_types_by_name['PrepareCommandRequest']
_PREPARECOMMANDRESPONSE = DESCRIPTOR.message_types_by_name['PrepareCommandResponse']
_DEVICEPARKREQUEST = DESCRIPTOR.message_types_by_name['DeviceParkRequest']
_DEVICEISPARKEDRESPONSE = DESCRIPTOR.message_types_by_name['DeviceIsParkedResponse']
_LOCKSTEPENABLEREQUEST = DESCRIPTOR.message_types_by_name['LockstepEnableRequest']
_LOCKSTEPDISABLEREQUEST = DESCRIPTOR.message_types_by_name['LockstepDisableRequest']
_LOCKSTEPSTOPREQUEST = DESCRIPTOR.message_types_by_name['LockstepStopRequest']
_LOCKSTEPHOMEREQUEST = DESCRIPTOR.message_types_by_name['LockstepHomeRequest']
_LOCKSTEPMOVEREQUEST = DESCRIPTOR.message_types_by_name['LockstepMoveRequest']
_LOCKSTEPWAITUNTILIDLEREQUEST = DESCRIPTOR.message_types_by_name['LockstepWaitUntilIdleRequest']
_LOCKSTEPISBUSYREQUEST = DESCRIPTOR.message_types_by_name['LockstepIsBusyRequest']
_LOCKSTEPISBUSYRESPONSE = DESCRIPTOR.message_types_by_name['LockstepIsBusyResponse']
_LOCKSTEPGETAXESREQUEST = DESCRIPTOR.message_types_by_name['LockstepGetAxesRequest']
_LOCKSTEPAXES = DESCRIPTOR.message_types_by_name['LockstepAxes']
_LOCKSTEPGETAXESRESPONSE = DESCRIPTOR.message_types_by_name['LockstepGetAxesResponse']
_LOCKSTEPGETAXISNUMBERSREQUEST = DESCRIPTOR.message_types_by_name['LockstepGetAxisNumbersRequest']
_LOCKSTEPGETAXISNUMBERSRESPONSE = DESCRIPTOR.message_types_by_name['LockstepGetAxisNumbersResponse']
_LOCKSTEPGETTWISTSREQUEST = DESCRIPTOR.message_types_by_name['LockstepGetTwistsRequest']
_LOCKSTEPGETTWISTSRESPONSE = DESCRIPTOR.message_types_by_name['LockstepGetTwistsResponse']
_LOCKSTEPGETOFFSETSREQUEST = DESCRIPTOR.message_types_by_name['LockstepGetOffsetsRequest']
_LOCKSTEPGETOFFSETSRESPONSE = DESCRIPTOR.message_types_by_name['LockstepGetOffsetsResponse']
_LOCKSTEPISENABLEDREQUEST = DESCRIPTOR.message_types_by_name['LockstepIsEnabledRequest']
_LOCKSTEPISENABLEDRESPONSE = DESCRIPTOR.message_types_by_name['LockstepIsEnabledResponse']
_LOCKSTEPTOSTRINGREQUEST = DESCRIPTOR.message_types_by_name['LockstepToStringRequest']
_LOCKSTEPTOSTRINGRESPONSE = DESCRIPTOR.message_types_by_name['LockstepToStringResponse']
_OSCILLOSCOPEADDCHANNELREQUEST = DESCRIPTOR.message_types_by_name['OscilloscopeAddChannelRequest']
_OSCILLOSCOPECLEARCHANNELSREQUEST = DESCRIPTOR.message_types_by_name['OscilloscopeClearChannelsRequest']
_OSCILLOSCOPESTARTSTOPREQUEST = DESCRIPTOR.message_types_by_name['OscilloscopeStartStopRequest']
_OSCILLOSCOPEREADREQUEST = DESCRIPTOR.message_types_by_name['OscilloscopeReadRequest']
_OSCILLOSCOPEREADRESPONSE = DESCRIPTOR.message_types_by_name['OscilloscopeReadResponse']
_OSCILLOSCOPEDATAIDENTIFIER = DESCRIPTOR.message_types_by_name['OscilloscopeDataIdentifier']
_OSCILLOSCOPECAPTUREPROPERTIES = DESCRIPTOR.message_types_by_name['OscilloscopeCaptureProperties']
_OSCILLOSCOPEDATAGETPROPERTIESRESPONSE = DESCRIPTOR.message_types_by_name['OscilloscopeDataGetPropertiesResponse']
_OSCILLOSCOPEDATAGETSAVEDSETTINGREQUEST = DESCRIPTOR.message_types_by_name['OscilloscopeDataGetSavedSettingRequest']
_OSCILLOSCOPEDATAGETSAVEDSETTINGRESPONSE = DESCRIPTOR.message_types_by_name['OscilloscopeDataGetSavedSettingResponse']
_OSCILLOSCOPEDATAGETSAMPLETIMEREQUEST = DESCRIPTOR.message_types_by_name['OscilloscopeDataGetSampleTimeRequest']
_OSCILLOSCOPEDATAGETSAMPLESREQUEST = DESCRIPTOR.message_types_by_name['OscilloscopeDataGetSamplesRequest']
_OSCILLOSCOPEDATAGETSAMPLESRESPONSE = DESCRIPTOR.message_types_by_name['OscilloscopeDataGetSamplesResponse']
_STREAMSETUPLIVEREQUEST = DESCRIPTOR.message_types_by_name['StreamSetupLiveRequest']
_STREAMSETUPLIVECOMPOSITEREQUEST = DESCRIPTOR.message_types_by_name['StreamSetupLiveCompositeRequest']
_STREAMSETUPSTOREREQUEST = DESCRIPTOR.message_types_by_name['StreamSetupStoreRequest']
_STREAMSETUPSTORECOMPOSITEREQUEST = DESCRIPTOR.message_types_by_name['StreamSetupStoreCompositeRequest']
_STREAMSETUPSTOREARBITRARYAXESREQUEST = DESCRIPTOR.message_types_by_name['StreamSetupStoreArbitraryAxesRequest']
_STREAMCALLREQUEST = DESCRIPTOR.message_types_by_name['StreamCallRequest']
_STREAMLINEREQUEST = DESCRIPTOR.message_types_by_name['StreamLineRequest']
_STREAMARCREQUEST = DESCRIPTOR.message_types_by_name['StreamArcRequest']
_STREAMCIRCLEREQUEST = DESCRIPTOR.message_types_by_name['StreamCircleRequest']
_STREAMWAITDIGITALINPUTREQUEST = DESCRIPTOR.message_types_by_name['StreamWaitDigitalInputRequest']
_STREAMWAITANALOGINPUTREQUEST = DESCRIPTOR.message_types_by_name['StreamWaitAnalogInputRequest']
_STREAMSETDIGITALOUTPUTREQUEST = DESCRIPTOR.message_types_by_name['StreamSetDigitalOutputRequest']
_STREAMSETANALOGOUTPUTREQUEST = DESCRIPTOR.message_types_by_name['StreamSetAnalogOutputRequest']
_STREAMTOGGLEDIGITALOUTPUTREQUEST = DESCRIPTOR.message_types_by_name['StreamToggleDigitalOutputRequest']
_STREAMSETALLDIGITALOUTPUTSREQUEST = DESCRIPTOR.message_types_by_name['StreamSetAllDigitalOutputsRequest']
_STREAMSETALLANALOGOUTPUTSREQUEST = DESCRIPTOR.message_types_by_name['StreamSetAllAnalogOutputsRequest']
_STREAMWAITREQUEST = DESCRIPTOR.message_types_by_name['StreamWaitRequest']
_STREAMWAITUNTILIDLEREQUEST = DESCRIPTOR.message_types_by_name['StreamWaitUntilIdleRequest']
_STREAMCORKREQUEST = DESCRIPTOR.message_types_by_name['StreamCorkRequest']
_STREAMUNCORKREQUEST = DESCRIPTOR.message_types_by_name['StreamUncorkRequest']
_STREAMISBUSYREQUEST = DESCRIPTOR.message_types_by_name['StreamIsBusyRequest']
_STREAMISBUSYRESPONSE = DESCRIPTOR.message_types_by_name['StreamIsBusyResponse']
_STREAMGETAXESREQUEST = DESCRIPTOR.message_types_by_name['StreamGetAxesRequest']
_STREAMGETAXESRESPONSE = DESCRIPTOR.message_types_by_name['StreamGetAxesResponse']
_STREAMGETMODEREQUEST = DESCRIPTOR.message_types_by_name['StreamGetModeRequest']
_STREAMGETMODERESPONSE = DESCRIPTOR.message_types_by_name['StreamGetModeResponse']
_STREAMGETMAXSPEEDREQUEST = DESCRIPTOR.message_types_by_name['StreamGetMaxSpeedRequest']
_STREAMGETMAXSPEEDRESPONSE = DESCRIPTOR.message_types_by_name['StreamGetMaxSpeedResponse']
_STREAMSETMAXSPEEDREQUEST = DESCRIPTOR.message_types_by_name['StreamSetMaxSpeedRequest']
_STREAMGETMAXTANGENTIALACCELERATIONREQUEST = DESCRIPTOR.message_types_by_name['StreamGetMaxTangentialAccelerationRequest']
_STREAMGETMAXTANGENTIALACCELERATIONRESPONSE = DESCRIPTOR.message_types_by_name['StreamGetMaxTangentialAccelerationResponse']
_STREAMSETMAXTANGENTIALACCELERATIONREQUEST = DESCRIPTOR.message_types_by_name['StreamSetMaxTangentialAccelerationRequest']
_STREAMGETMAXCENTRIPETALACCELERATIONREQUEST = DESCRIPTOR.message_types_by_name['StreamGetMaxCentripetalAccelerationRequest']
_STREAMGETMAXCENTRIPETALACCELERATIONRESPONSE = DESCRIPTOR.message_types_by_name['StreamGetMaxCentripetalAccelerationResponse']
_STREAMSETMAXCENTRIPETALACCELERATIONREQUEST = DESCRIPTOR.message_types_by_name['StreamSetMaxCentripetalAccelerationRequest']
_STREAMTOSTRINGREQUEST = DESCRIPTOR.message_types_by_name['StreamToStringRequest']
_STREAMTOSTRINGRESPONSE = DESCRIPTOR.message_types_by_name['StreamToStringResponse']
_STREAMDISABLEREQUEST = DESCRIPTOR.message_types_by_name['StreamDisableRequest']
_STREAMBUFFERGETCONTENTREQUEST = DESCRIPTOR.message_types_by_name['StreamBufferGetContentRequest']
_STREAMBUFFERGETCONTENTRESPONSE = DESCRIPTOR.message_types_by_name['StreamBufferGetContentResponse']
_STREAMBUFFERERASEREQUEST = DESCRIPTOR.message_types_by_name['StreamBufferEraseRequest']
_STREAMGENERICCOMMANDREQUEST = DESCRIPTOR.message_types_by_name['StreamGenericCommandRequest']
_STREAMGENERICCOMMANDBATCHREQUEST = DESCRIPTOR.message_types_by_name['StreamGenericCommandBatchRequest']
_BINARYREPLYONLYEVENT = DESCRIPTOR.message_types_by_name['BinaryReplyOnlyEvent']
_OPENBINARYINTERFACEREQUEST = DESCRIPTOR.message_types_by_name['OpenBinaryInterfaceRequest']
_UNKNOWNBINARYRESPONSEEVENT = DESCRIPTOR.message_types_by_name['UnknownBinaryResponseEvent']
_GENERICBINARYREQUEST = DESCRIPTOR.message_types_by_name['GenericBinaryRequest']
_BINARYMESSAGE = DESCRIPTOR.message_types_by_name['BinaryMessage']
_BINARYMESSAGECOLLECTION = DESCRIPTOR.message_types_by_name['BinaryMessageCollection']
_BINARYDEVICERENUMBERREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceRenumberRequest']
_BINARYDEVICERENUMBERRESPONSE = DESCRIPTOR.message_types_by_name['BinaryDeviceRenumberResponse']
_BINARYDEVICEIDENTIFYREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceIdentifyRequest']
_BINARYDEVICEIDENTITY = DESCRIPTOR.message_types_by_name['BinaryDeviceIdentity']
_BINARYDEVICEGETIDENTITYREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceGetIdentityRequest']
_BINARYDEVICEGETIDENTITYRESPONSE = DESCRIPTOR.message_types_by_name['BinaryDeviceGetIdentityResponse']
_BINARYDEVICEGETISIDENTIFIEDREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceGetIsIdentifiedRequest']
_BINARYDEVICEGETISIDENTIFIEDRESPONSE = DESCRIPTOR.message_types_by_name['BinaryDeviceGetIsIdentifiedResponse']
_BINARYGENERICWITHUNITSREQUEST = DESCRIPTOR.message_types_by_name['BinaryGenericWithUnitsRequest']
_BINARYGENERICWITHUNITSRESPONSE = DESCRIPTOR.message_types_by_name['BinaryGenericWithUnitsResponse']
_BINARYDEVICEHOMEREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceHomeRequest']
_BINARYDEVICEMOVEMENTRESPONSE = DESCRIPTOR.message_types_by_name['BinaryDeviceMovementResponse']
_BINARYDEVICEMOVEREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceMoveRequest']
_BINARYDEVICESTOPREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceStopRequest']
_BINARYDEVICEWAITUNTILIDLEREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceWaitUntilIdleRequest']
_BINARYDEVICEISBUSYREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceIsBusyRequest']
_BINARYDEVICEISBUSYRESPONSE = DESCRIPTOR.message_types_by_name['BinaryDeviceIsBusyResponse']
_BINARYDEVICEDETECTREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceDetectRequest']
_BINARYDEVICEDETECTRESPONSE = DESCRIPTOR.message_types_by_name['BinaryDeviceDetectResponse']
_BINARYDEVICEGETSETTINGREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceGetSettingRequest']
_BINARYDEVICEGETSETTINGRESPONSE = DESCRIPTOR.message_types_by_name['BinaryDeviceGetSettingResponse']
_BINARYDEVICESETSETTINGREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceSetSettingRequest']
_BINARYDEVICEPARKREQUEST = DESCRIPTOR.message_types_by_name['BinaryDeviceParkRequest']
_BINARYDEVICEPARKRESPONSE = DESCRIPTOR.message_types_by_name['BinaryDeviceParkResponse']
_CUSTOMINTERFACEREADREQUEST = DESCRIPTOR.message_types_by_name['CustomInterfaceReadRequest']
_CUSTOMINTERFACEREADRESPONSE = DESCRIPTOR.message_types_by_name['CustomInterfaceReadResponse']
_CUSTOMINTERFACEWRITEREQUEST = DESCRIPTOR.message_types_by_name['CustomInterfaceWriteRequest']
_CUSTOMINTERFACEOPENRESPONSE = DESCRIPTOR.message_types_by_name['CustomInterfaceOpenResponse']
_CUSTOMINTERFACECLOSEREQUEST = DESCRIPTOR.message_types_by_name['CustomInterfaceCloseRequest']
_GETSTATEREQUEST = DESCRIPTOR.message_types_by_name['GetStateRequest']
_GETSTATERESPONSE = DESCRIPTOR.message_types_by_name['GetStateResponse']
_CANSETSTATEREQUEST = DESCRIPTOR.message_types_by_name['CanSetStateRequest']
_CANSETSTATEAXISRESPONSE = DESCRIPTOR.message_types_by_name['CanSetStateAxisResponse']
_CANSETSTATEDEVICERESPONSE = DESCRIPTOR.message_types_by_name['CanSetStateDeviceResponse']
_SETSTATEREQUEST = DESCRIPTOR.message_types_by_name['SetStateRequest']
_SERVOTUNINGREQUEST = DESCRIPTOR.message_types_by_name['ServoTuningRequest']
_SERVOTUNINGPARAM = DESCRIPTOR.message_types_by_name['ServoTuningParam']
_PARAMSETINFO = DESCRIPTOR.message_types_by_name['ParamsetInfo']
_SETSERVOTUNINGREQUEST = DESCRIPTOR.message_types_by_name['SetServoTuningRequest']
_GETSTARTUPPARAMSET = DESCRIPTOR.message_types_by_name['GetStartupParamset']
_STARTUPPARAMSET = DESCRIPTOR.message_types_by_name['StartupParamset']
_LOADPARAMSET = DESCRIPTOR.message_types_by_name['LoadParamset']
_SETSERVOTUNINGPIDREQUEST = DESCRIPTOR.message_types_by_name['SetServoTuningPIDRequest']
_PIDTUNING = DESCRIPTOR.message_types_by_name['PidTuning']
_GETSIMPLETUNINGPARAMLISTREQUEST = DESCRIPTOR.message_types_by_name['GetSimpleTuningParamListRequest']
_SETSIMPLETUNING = DESCRIPTOR.message_types_by_name['SetSimpleTuning']
_SIMPLETUNINGPARAM = DESCRIPTOR.message_types_by_name['SimpleTuningParam']
_SIMPLETUNINGPARAMLIST = DESCRIPTOR.message_types_by_name['SimpleTuningParamList']
_TRANSLATORCREATEREQUEST = DESCRIPTOR.message_types_by_name['TranslatorCreateRequest']
_TRANSLATORCREATERESPONSE = DESCRIPTOR.message_types_by_name['TranslatorCreateResponse']
_TRANSLATORAXISDEFINITION = DESCRIPTOR.message_types_by_name['TranslatorAxisDefinition']
_TRANSLATORDEFINITION = DESCRIPTOR.message_types_by_name['TranslatorDefinition']
_TRANSLATORCONFIG = DESCRIPTOR.message_types_by_name['TranslatorConfig']
_TRANSLATORAXISMAPPING = DESCRIPTOR.message_types_by_name['TranslatorAxisMapping']
_TRANSLATORAXISTRANSFORMATION = DESCRIPTOR.message_types_by_name['TranslatorAxisTransformation']
_TRANSLATORTRANSLATEREQUEST = DESCRIPTOR.message_types_by_name['TranslatorTranslateRequest']
_TRANSLATEMESSAGE = DESCRIPTOR.message_types_by_name['TranslateMessage']
_TRANSLATORTRANSLATERESPONSE = DESCRIPTOR.message_types_by_name['TranslatorTranslateResponse']
_GCODESYNTAXEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['GCodeSyntaxExceptionData']
_GCODEEXECUTIONEXCEPTIONDATA = DESCRIPTOR.message_types_by_name['GCodeExecutionExceptionData']
_TRANSLATORFLUSHLIVEREQUEST = DESCRIPTOR.message_types_by_name['TranslatorFlushLiveRequest']
_TRANSLATORFLUSHRESPONSE = DESCRIPTOR.message_types_by_name['TranslatorFlushResponse']
_TRANSLATORCREATELIVEREQUEST = DESCRIPTOR.message_types_by_name['TranslatorCreateLiveRequest']
_TRANSLATOREMPTYREQUEST = DESCRIPTOR.message_types_by_name['TranslatorEmptyRequest']
_TRANSLATORSETTRAVERSERATEREQUEST = DESCRIPTOR.message_types_by_name['TranslatorSetTraverseRateRequest']
_TRANSLATORSETAXISPOSITIONREQUEST = DESCRIPTOR.message_types_by_name['TranslatorSetAxisPositionRequest']
_TRANSLATORGETAXISPOSITIONREQUEST = DESCRIPTOR.message_types_by_name['TranslatorGetAxisPositionRequest']
_TRANSLATORGETAXISPOSITIONRESPONSE = DESCRIPTOR.message_types_by_name['TranslatorGetAxisPositionResponse']
_TRANSLATORGETAXISOFFSETREQUEST = DESCRIPTOR.message_types_by_name['TranslatorGetAxisOffsetRequest']
_TRANSLATORGETCURRENTCOORDINATESYSTEMRESPONSE = DESCRIPTOR.message_types_by_name['TranslatorGetCurrentCoordinateSystemResponse']
_TRANSLATORSETFEEDRATEOVERRIDEREQUEST = DESCRIPTOR.message_types_by_name['TranslatorSetFeedRateOverrideRequest']
_RESPONSE_RESPONSETYPE = _RESPONSE.enum_types_by_name['ResponseType']
_AXISIDENTITY_AXISTYPE = _AXISIDENTITY.enum_types_by_name['AxisType']
_DEVICEMOVEREQUEST_MOVETYPE = _DEVICEMOVEREQUEST.enum_types_by_name['MoveType']
_LOCKSTEPMOVEREQUEST_MOVETYPE = _LOCKSTEPMOVEREQUEST.enum_types_by_name['MoveType']
_STREAMLINEREQUEST_TYPE = _STREAMLINEREQUEST.enum_types_by_name['Type']
_STREAMARCREQUEST_TYPE = _STREAMARCREQUEST.enum_types_by_name['Type']
_STREAMCIRCLEREQUEST_TYPE = _STREAMCIRCLEREQUEST.enum_types_by_name['Type']
_BINARYDEVICEIDENTITY_DEVICETYPE = _BINARYDEVICEIDENTITY.enum_types_by_name['DeviceType']
_BINARYDEVICEMOVEREQUEST_MOVETYPE = _BINARYDEVICEMOVEREQUEST.enum_types_by_name['MoveType']
Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Request)
  })
_sym_db.RegisterMessage(Request)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Response)
  })
_sym_db.RegisterMessage(Response)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Event)
  })
_sym_db.RegisterMessage(Event)

EmptyRequest = _reflection.GeneratedProtocolMessageType('EmptyRequest', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.EmptyRequest)
  })
_sym_db.RegisterMessage(EmptyRequest)

AxisIdentity = _reflection.GeneratedProtocolMessageType('AxisIdentity', (_message.Message,), {
  'DESCRIPTOR' : _AXISIDENTITY,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.AxisIdentity)
  })
_sym_db.RegisterMessage(AxisIdentity)

DeviceIdentity = _reflection.GeneratedProtocolMessageType('DeviceIdentity', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIDENTITY,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIdentity)
  })
_sym_db.RegisterMessage(DeviceIdentity)

FirmwareVersion = _reflection.GeneratedProtocolMessageType('FirmwareVersion', (_message.Message,), {
  'DESCRIPTOR' : _FIRMWAREVERSION,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.FirmwareVersion)
  })
_sym_db.RegisterMessage(FirmwareVersion)

DeviceIOInfo = _reflection.GeneratedProtocolMessageType('DeviceIOInfo', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIOINFO,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIOInfo)
  })
_sym_db.RegisterMessage(DeviceIOInfo)

Measurement = _reflection.GeneratedProtocolMessageType('Measurement', (_message.Message,), {
  'DESCRIPTOR' : _MEASUREMENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Measurement)
  })
_sym_db.RegisterMessage(Measurement)

StreamAxisDefinition = _reflection.GeneratedProtocolMessageType('StreamAxisDefinition', (_message.Message,), {
  'DESCRIPTOR' : _STREAMAXISDEFINITION,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamAxisDefinition)
  })
_sym_db.RegisterMessage(StreamAxisDefinition)

InvalidPacketExceptionData = _reflection.GeneratedProtocolMessageType('InvalidPacketExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _INVALIDPACKETEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.InvalidPacketExceptionData)
  })
_sym_db.RegisterMessage(InvalidPacketExceptionData)

DeviceAddressConflictExceptionData = _reflection.GeneratedProtocolMessageType('DeviceAddressConflictExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEADDRESSCONFLICTEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceAddressConflictExceptionData)
  })
_sym_db.RegisterMessage(DeviceAddressConflictExceptionData)

MovementInterruptedExceptionData = _reflection.GeneratedProtocolMessageType('MovementInterruptedExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _MOVEMENTINTERRUPTEDEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.MovementInterruptedExceptionData)
  })
_sym_db.RegisterMessage(MovementInterruptedExceptionData)

StreamMovementInterruptedExceptionData = _reflection.GeneratedProtocolMessageType('StreamMovementInterruptedExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMOVEMENTINTERRUPTEDEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamMovementInterruptedExceptionData)
  })
_sym_db.RegisterMessage(StreamMovementInterruptedExceptionData)

MovementFailedExceptionData = _reflection.GeneratedProtocolMessageType('MovementFailedExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _MOVEMENTFAILEDEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.MovementFailedExceptionData)
  })
_sym_db.RegisterMessage(MovementFailedExceptionData)

StreamMovementFailedExceptionData = _reflection.GeneratedProtocolMessageType('StreamMovementFailedExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMOVEMENTFAILEDEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamMovementFailedExceptionData)
  })
_sym_db.RegisterMessage(StreamMovementFailedExceptionData)

StreamExecutionExceptionData = _reflection.GeneratedProtocolMessageType('StreamExecutionExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEXECUTIONEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamExecutionExceptionData)
  })
_sym_db.RegisterMessage(StreamExecutionExceptionData)

InvalidResponseExceptionData = _reflection.GeneratedProtocolMessageType('InvalidResponseExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _INVALIDRESPONSEEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.InvalidResponseExceptionData)
  })
_sym_db.RegisterMessage(InvalidResponseExceptionData)

CommandFailedExceptionData = _reflection.GeneratedProtocolMessageType('CommandFailedExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDFAILEDEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CommandFailedExceptionData)
  })
_sym_db.RegisterMessage(CommandFailedExceptionData)

BinaryCommandFailedExceptionData = _reflection.GeneratedProtocolMessageType('BinaryCommandFailedExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _BINARYCOMMANDFAILEDEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryCommandFailedExceptionData)
  })
_sym_db.RegisterMessage(BinaryCommandFailedExceptionData)

SetPeripheralStateExceptionData = _reflection.GeneratedProtocolMessageType('SetPeripheralStateExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _SETPERIPHERALSTATEEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetPeripheralStateExceptionData)
  })
_sym_db.RegisterMessage(SetPeripheralStateExceptionData)

SetDeviceStateExceptionData = _reflection.GeneratedProtocolMessageType('SetDeviceStateExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _SETDEVICESTATEEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetDeviceStateExceptionData)
  })
_sym_db.RegisterMessage(SetDeviceStateExceptionData)

TestRequest = _reflection.GeneratedProtocolMessageType('TestRequest', (_message.Message,), {
  'DESCRIPTOR' : _TESTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TestRequest)
  })
_sym_db.RegisterMessage(TestRequest)

TestResponse = _reflection.GeneratedProtocolMessageType('TestResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TestResponse)
  })
_sym_db.RegisterMessage(TestResponse)

TestResponseLong = _reflection.GeneratedProtocolMessageType('TestResponseLong', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESPONSELONG,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TestResponseLong)
  })
_sym_db.RegisterMessage(TestResponseLong)

TestEvent = _reflection.GeneratedProtocolMessageType('TestEvent', (_message.Message,), {
  'DESCRIPTOR' : _TESTEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TestEvent)
  })
_sym_db.RegisterMessage(TestEvent)

ToolsListSerialPortsResponse = _reflection.GeneratedProtocolMessageType('ToolsListSerialPortsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOOLSLISTSERIALPORTSRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToolsListSerialPortsResponse)
  })
_sym_db.RegisterMessage(ToolsListSerialPortsResponse)

GetMessageRouterPipeResponse = _reflection.GeneratedProtocolMessageType('GetMessageRouterPipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMESSAGEROUTERPIPERESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GetMessageRouterPipeResponse)
  })
_sym_db.RegisterMessage(GetMessageRouterPipeResponse)

SetDeviceDbSourceRequest = _reflection.GeneratedProtocolMessageType('SetDeviceDbSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDEVICEDBSOURCEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetDeviceDbSourceRequest)
  })
_sym_db.RegisterMessage(SetDeviceDbSourceRequest)

ToggleDeviceDbStoreRequest = _reflection.GeneratedProtocolMessageType('ToggleDeviceDbStoreRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEDEVICEDBSTOREREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToggleDeviceDbStoreRequest)
  })
_sym_db.RegisterMessage(ToggleDeviceDbStoreRequest)

OpenInterfaceRequest = _reflection.GeneratedProtocolMessageType('OpenInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _OPENINTERFACEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OpenInterfaceRequest)
  })
_sym_db.RegisterMessage(OpenInterfaceRequest)

OpenInterfaceResponse = _reflection.GeneratedProtocolMessageType('OpenInterfaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _OPENINTERFACERESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OpenInterfaceResponse)
  })
_sym_db.RegisterMessage(OpenInterfaceResponse)

CloseInterfaceRequest = _reflection.GeneratedProtocolMessageType('CloseInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOSEINTERFACEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CloseInterfaceRequest)
  })
_sym_db.RegisterMessage(CloseInterfaceRequest)

EmptyInterfaceRequest = _reflection.GeneratedProtocolMessageType('EmptyInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYINTERFACEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.EmptyInterfaceRequest)
  })
_sym_db.RegisterMessage(EmptyInterfaceRequest)

GetInterfaceTimeoutResponse = _reflection.GeneratedProtocolMessageType('GetInterfaceTimeoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERFACETIMEOUTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GetInterfaceTimeoutResponse)
  })
_sym_db.RegisterMessage(GetInterfaceTimeoutResponse)

SetInterfaceTimeoutRequest = _reflection.GeneratedProtocolMessageType('SetInterfaceTimeoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETINTERFACETIMEOUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetInterfaceTimeoutRequest)
  })
_sym_db.RegisterMessage(SetInterfaceTimeoutRequest)

GetInterfaceChecksumEnabledResponse = _reflection.GeneratedProtocolMessageType('GetInterfaceChecksumEnabledResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERFACECHECKSUMENABLEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GetInterfaceChecksumEnabledResponse)
  })
_sym_db.RegisterMessage(GetInterfaceChecksumEnabledResponse)

SetInterfaceChecksumEnabledRequest = _reflection.GeneratedProtocolMessageType('SetInterfaceChecksumEnabledRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETINTERFACECHECKSUMENABLEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetInterfaceChecksumEnabledRequest)
  })
_sym_db.RegisterMessage(SetInterfaceChecksumEnabledRequest)

ToStringRequest = _reflection.GeneratedProtocolMessageType('ToStringRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOSTRINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToStringRequest)
  })
_sym_db.RegisterMessage(ToStringRequest)

ToStringResponse = _reflection.GeneratedProtocolMessageType('ToStringResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOSTRINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToStringResponse)
  })
_sym_db.RegisterMessage(ToStringResponse)

GenericCommandRequest = _reflection.GeneratedProtocolMessageType('GenericCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERICCOMMANDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GenericCommandRequest)
  })
_sym_db.RegisterMessage(GenericCommandRequest)

GenericCommandResponse = _reflection.GeneratedProtocolMessageType('GenericCommandResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERICCOMMANDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GenericCommandResponse)
  })
_sym_db.RegisterMessage(GenericCommandResponse)

GenericCommandResponseCollection = _reflection.GeneratedProtocolMessageType('GenericCommandResponseCollection', (_message.Message,), {
  'DESCRIPTOR' : _GENERICCOMMANDRESPONSECOLLECTION,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GenericCommandResponseCollection)
  })
_sym_db.RegisterMessage(GenericCommandResponseCollection)

UnknownResponseEvent = _reflection.GeneratedProtocolMessageType('UnknownResponseEvent', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNRESPONSEEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.UnknownResponseEvent)
  })
_sym_db.RegisterMessage(UnknownResponseEvent)

AlertEvent = _reflection.GeneratedProtocolMessageType('AlertEvent', (_message.Message,), {
  'DESCRIPTOR' : _ALERTEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.AlertEvent)
  })
_sym_db.RegisterMessage(AlertEvent)

DisconnectedEvent = _reflection.GeneratedProtocolMessageType('DisconnectedEvent', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTEDEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DisconnectedEvent)
  })
_sym_db.RegisterMessage(DisconnectedEvent)

DeviceRenumberRequest = _reflection.GeneratedProtocolMessageType('DeviceRenumberRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICERENUMBERREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceRenumberRequest)
  })
_sym_db.RegisterMessage(DeviceRenumberRequest)

DeviceRenumberResponse = _reflection.GeneratedProtocolMessageType('DeviceRenumberResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICERENUMBERRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceRenumberResponse)
  })
_sym_db.RegisterMessage(DeviceRenumberResponse)

DeviceDetectRequest = _reflection.GeneratedProtocolMessageType('DeviceDetectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEDETECTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceDetectRequest)
  })
_sym_db.RegisterMessage(DeviceDetectRequest)

DeviceDetectResponse = _reflection.GeneratedProtocolMessageType('DeviceDetectResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEDETECTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceDetectResponse)
  })
_sym_db.RegisterMessage(DeviceDetectResponse)

DeviceHomeRequest = _reflection.GeneratedProtocolMessageType('DeviceHomeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEHOMEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceHomeRequest)
  })
_sym_db.RegisterMessage(DeviceHomeRequest)

DeviceWaitUntilIdleRequest = _reflection.GeneratedProtocolMessageType('DeviceWaitUntilIdleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEWAITUNTILIDLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceWaitUntilIdleRequest)
  })
_sym_db.RegisterMessage(DeviceWaitUntilIdleRequest)

DeviceMoveRequest = _reflection.GeneratedProtocolMessageType('DeviceMoveRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEMOVEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceMoveRequest)
  })
_sym_db.RegisterMessage(DeviceMoveRequest)

DeviceStopRequest = _reflection.GeneratedProtocolMessageType('DeviceStopRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESTOPREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceStopRequest)
  })
_sym_db.RegisterMessage(DeviceStopRequest)

DeviceIdentifyRequest = _reflection.GeneratedProtocolMessageType('DeviceIdentifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIDENTIFYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIdentifyRequest)
  })
_sym_db.RegisterMessage(DeviceIdentifyRequest)

DeviceOnAllRequest = _reflection.GeneratedProtocolMessageType('DeviceOnAllRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEONALLREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceOnAllRequest)
  })
_sym_db.RegisterMessage(DeviceOnAllRequest)

DeviceOnAllResponse = _reflection.GeneratedProtocolMessageType('DeviceOnAllResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEONALLRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceOnAllResponse)
  })
_sym_db.RegisterMessage(DeviceOnAllResponse)

DeviceGetIdentityRequest = _reflection.GeneratedProtocolMessageType('DeviceGetIdentityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETIDENTITYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIdentityRequest)
  })
_sym_db.RegisterMessage(DeviceGetIdentityRequest)

DeviceGetIdentityResponse = _reflection.GeneratedProtocolMessageType('DeviceGetIdentityResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETIDENTITYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIdentityResponse)
  })
_sym_db.RegisterMessage(DeviceGetIdentityResponse)

DeviceGetIsIdentifiedRequest = _reflection.GeneratedProtocolMessageType('DeviceGetIsIdentifiedRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETISIDENTIFIEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIsIdentifiedRequest)
  })
_sym_db.RegisterMessage(DeviceGetIsIdentifiedRequest)

DeviceGetIsIdentifiedResponse = _reflection.GeneratedProtocolMessageType('DeviceGetIsIdentifiedResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETISIDENTIFIEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIsIdentifiedResponse)
  })
_sym_db.RegisterMessage(DeviceGetIsIdentifiedResponse)

DeviceGetAxisIdentityRequest = _reflection.GeneratedProtocolMessageType('DeviceGetAxisIdentityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETAXISIDENTITYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAxisIdentityRequest)
  })
_sym_db.RegisterMessage(DeviceGetAxisIdentityRequest)

DeviceGetAxisIdentityResponse = _reflection.GeneratedProtocolMessageType('DeviceGetAxisIdentityResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETAXISIDENTITYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAxisIdentityResponse)
  })
_sym_db.RegisterMessage(DeviceGetAxisIdentityResponse)

DeviceIsBusyRequest = _reflection.GeneratedProtocolMessageType('DeviceIsBusyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISBUSYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIsBusyRequest)
  })
_sym_db.RegisterMessage(DeviceIsBusyRequest)

DeviceIsBusyResponse = _reflection.GeneratedProtocolMessageType('DeviceIsBusyResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISBUSYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIsBusyResponse)
  })
_sym_db.RegisterMessage(DeviceIsBusyResponse)

DeviceGetWarningsRequest = _reflection.GeneratedProtocolMessageType('DeviceGetWarningsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETWARNINGSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetWarningsRequest)
  })
_sym_db.RegisterMessage(DeviceGetWarningsRequest)

DeviceGetWarningsResponse = _reflection.GeneratedProtocolMessageType('DeviceGetWarningsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETWARNINGSRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetWarningsResponse)
  })
_sym_db.RegisterMessage(DeviceGetWarningsResponse)

DeviceGetAllDigitalIORequest = _reflection.GeneratedProtocolMessageType('DeviceGetAllDigitalIORequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETALLDIGITALIOREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAllDigitalIORequest)
  })
_sym_db.RegisterMessage(DeviceGetAllDigitalIORequest)

DeviceGetAllDigitalIOResponse = _reflection.GeneratedProtocolMessageType('DeviceGetAllDigitalIOResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETALLDIGITALIORESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAllDigitalIOResponse)
  })
_sym_db.RegisterMessage(DeviceGetAllDigitalIOResponse)

DeviceGetAllAnalogIORequest = _reflection.GeneratedProtocolMessageType('DeviceGetAllAnalogIORequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETALLANALOGIOREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAllAnalogIORequest)
  })
_sym_db.RegisterMessage(DeviceGetAllAnalogIORequest)

DeviceGetAllAnalogIOResponse = _reflection.GeneratedProtocolMessageType('DeviceGetAllAnalogIOResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETALLANALOGIORESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAllAnalogIOResponse)
  })
_sym_db.RegisterMessage(DeviceGetAllAnalogIOResponse)

DeviceGetDigitalIORequest = _reflection.GeneratedProtocolMessageType('DeviceGetDigitalIORequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETDIGITALIOREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetDigitalIORequest)
  })
_sym_db.RegisterMessage(DeviceGetDigitalIORequest)

DeviceGetDigitalIOResponse = _reflection.GeneratedProtocolMessageType('DeviceGetDigitalIOResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETDIGITALIORESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetDigitalIOResponse)
  })
_sym_db.RegisterMessage(DeviceGetDigitalIOResponse)

DeviceGetAnalogIORequest = _reflection.GeneratedProtocolMessageType('DeviceGetAnalogIORequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETANALOGIOREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAnalogIORequest)
  })
_sym_db.RegisterMessage(DeviceGetAnalogIORequest)

DeviceGetAnalogIOResponse = _reflection.GeneratedProtocolMessageType('DeviceGetAnalogIOResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETANALOGIORESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAnalogIOResponse)
  })
_sym_db.RegisterMessage(DeviceGetAnalogIOResponse)

DeviceSetAllDigitalOutputsRequest = _reflection.GeneratedProtocolMessageType('DeviceSetAllDigitalOutputsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESETALLDIGITALOUTPUTSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetAllDigitalOutputsRequest)
  })
_sym_db.RegisterMessage(DeviceSetAllDigitalOutputsRequest)

DeviceSetAllAnalogOutputsRequest = _reflection.GeneratedProtocolMessageType('DeviceSetAllAnalogOutputsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESETALLANALOGOUTPUTSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetAllAnalogOutputsRequest)
  })
_sym_db.RegisterMessage(DeviceSetAllAnalogOutputsRequest)

DeviceSetDigitalOutputRequest = _reflection.GeneratedProtocolMessageType('DeviceSetDigitalOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESETDIGITALOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetDigitalOutputRequest)
  })
_sym_db.RegisterMessage(DeviceSetDigitalOutputRequest)

DeviceSetAnalogOutputRequest = _reflection.GeneratedProtocolMessageType('DeviceSetAnalogOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESETANALOGOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetAnalogOutputRequest)
  })
_sym_db.RegisterMessage(DeviceSetAnalogOutputRequest)

DeviceGetIOChannelsInfoRequest = _reflection.GeneratedProtocolMessageType('DeviceGetIOChannelsInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETIOCHANNELSINFOREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIOChannelsInfoRequest)
  })
_sym_db.RegisterMessage(DeviceGetIOChannelsInfoRequest)

SetLogOutputRequest = _reflection.GeneratedProtocolMessageType('SetLogOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETLOGOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetLogOutputRequest)
  })
_sym_db.RegisterMessage(SetLogOutputRequest)

DeviceGetSettingRequest = _reflection.GeneratedProtocolMessageType('DeviceGetSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETSETTINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetSettingRequest)
  })
_sym_db.RegisterMessage(DeviceGetSettingRequest)

DeviceGetSettingResponse = _reflection.GeneratedProtocolMessageType('DeviceGetSettingResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETSETTINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetSettingResponse)
  })
_sym_db.RegisterMessage(DeviceGetSettingResponse)

DeviceGetSettingStrResponse = _reflection.GeneratedProtocolMessageType('DeviceGetSettingStrResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETSETTINGSTRRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetSettingStrResponse)
  })
_sym_db.RegisterMessage(DeviceGetSettingStrResponse)

DeviceConvertSettingRequest = _reflection.GeneratedProtocolMessageType('DeviceConvertSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICECONVERTSETTINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceConvertSettingRequest)
  })
_sym_db.RegisterMessage(DeviceConvertSettingRequest)

DeviceConvertSettingResponse = _reflection.GeneratedProtocolMessageType('DeviceConvertSettingResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICECONVERTSETTINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceConvertSettingResponse)
  })
_sym_db.RegisterMessage(DeviceConvertSettingResponse)

DeviceSetSettingRequest = _reflection.GeneratedProtocolMessageType('DeviceSetSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESETSETTINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetSettingRequest)
  })
_sym_db.RegisterMessage(DeviceSetSettingRequest)

DeviceSetSettingStrRequest = _reflection.GeneratedProtocolMessageType('DeviceSetSettingStrRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESETSETTINGSTRREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetSettingStrRequest)
  })
_sym_db.RegisterMessage(DeviceSetSettingStrRequest)

PrepareCommandRequest = _reflection.GeneratedProtocolMessageType('PrepareCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREPARECOMMANDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.PrepareCommandRequest)
  })
_sym_db.RegisterMessage(PrepareCommandRequest)

PrepareCommandResponse = _reflection.GeneratedProtocolMessageType('PrepareCommandResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREPARECOMMANDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.PrepareCommandResponse)
  })
_sym_db.RegisterMessage(PrepareCommandResponse)

DeviceParkRequest = _reflection.GeneratedProtocolMessageType('DeviceParkRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEPARKREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceParkRequest)
  })
_sym_db.RegisterMessage(DeviceParkRequest)

DeviceIsParkedResponse = _reflection.GeneratedProtocolMessageType('DeviceIsParkedResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISPARKEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIsParkedResponse)
  })
_sym_db.RegisterMessage(DeviceIsParkedResponse)

LockstepEnableRequest = _reflection.GeneratedProtocolMessageType('LockstepEnableRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPENABLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepEnableRequest)
  })
_sym_db.RegisterMessage(LockstepEnableRequest)

LockstepDisableRequest = _reflection.GeneratedProtocolMessageType('LockstepDisableRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPDISABLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepDisableRequest)
  })
_sym_db.RegisterMessage(LockstepDisableRequest)

LockstepStopRequest = _reflection.GeneratedProtocolMessageType('LockstepStopRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPSTOPREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepStopRequest)
  })
_sym_db.RegisterMessage(LockstepStopRequest)

LockstepHomeRequest = _reflection.GeneratedProtocolMessageType('LockstepHomeRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPHOMEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepHomeRequest)
  })
_sym_db.RegisterMessage(LockstepHomeRequest)

LockstepMoveRequest = _reflection.GeneratedProtocolMessageType('LockstepMoveRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPMOVEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepMoveRequest)
  })
_sym_db.RegisterMessage(LockstepMoveRequest)

LockstepWaitUntilIdleRequest = _reflection.GeneratedProtocolMessageType('LockstepWaitUntilIdleRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPWAITUNTILIDLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepWaitUntilIdleRequest)
  })
_sym_db.RegisterMessage(LockstepWaitUntilIdleRequest)

LockstepIsBusyRequest = _reflection.GeneratedProtocolMessageType('LockstepIsBusyRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPISBUSYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepIsBusyRequest)
  })
_sym_db.RegisterMessage(LockstepIsBusyRequest)

LockstepIsBusyResponse = _reflection.GeneratedProtocolMessageType('LockstepIsBusyResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPISBUSYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepIsBusyResponse)
  })
_sym_db.RegisterMessage(LockstepIsBusyResponse)

LockstepGetAxesRequest = _reflection.GeneratedProtocolMessageType('LockstepGetAxesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETAXESREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetAxesRequest)
  })
_sym_db.RegisterMessage(LockstepGetAxesRequest)

LockstepAxes = _reflection.GeneratedProtocolMessageType('LockstepAxes', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPAXES,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepAxes)
  })
_sym_db.RegisterMessage(LockstepAxes)

LockstepGetAxesResponse = _reflection.GeneratedProtocolMessageType('LockstepGetAxesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETAXESRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetAxesResponse)
  })
_sym_db.RegisterMessage(LockstepGetAxesResponse)

LockstepGetAxisNumbersRequest = _reflection.GeneratedProtocolMessageType('LockstepGetAxisNumbersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETAXISNUMBERSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetAxisNumbersRequest)
  })
_sym_db.RegisterMessage(LockstepGetAxisNumbersRequest)

LockstepGetAxisNumbersResponse = _reflection.GeneratedProtocolMessageType('LockstepGetAxisNumbersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETAXISNUMBERSRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetAxisNumbersResponse)
  })
_sym_db.RegisterMessage(LockstepGetAxisNumbersResponse)

LockstepGetTwistsRequest = _reflection.GeneratedProtocolMessageType('LockstepGetTwistsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETTWISTSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetTwistsRequest)
  })
_sym_db.RegisterMessage(LockstepGetTwistsRequest)

LockstepGetTwistsResponse = _reflection.GeneratedProtocolMessageType('LockstepGetTwistsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETTWISTSRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetTwistsResponse)
  })
_sym_db.RegisterMessage(LockstepGetTwistsResponse)

LockstepGetOffsetsRequest = _reflection.GeneratedProtocolMessageType('LockstepGetOffsetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETOFFSETSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetOffsetsRequest)
  })
_sym_db.RegisterMessage(LockstepGetOffsetsRequest)

LockstepGetOffsetsResponse = _reflection.GeneratedProtocolMessageType('LockstepGetOffsetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETOFFSETSRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetOffsetsResponse)
  })
_sym_db.RegisterMessage(LockstepGetOffsetsResponse)

LockstepIsEnabledRequest = _reflection.GeneratedProtocolMessageType('LockstepIsEnabledRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPISENABLEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepIsEnabledRequest)
  })
_sym_db.RegisterMessage(LockstepIsEnabledRequest)

LockstepIsEnabledResponse = _reflection.GeneratedProtocolMessageType('LockstepIsEnabledResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPISENABLEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepIsEnabledResponse)
  })
_sym_db.RegisterMessage(LockstepIsEnabledResponse)

LockstepToStringRequest = _reflection.GeneratedProtocolMessageType('LockstepToStringRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPTOSTRINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepToStringRequest)
  })
_sym_db.RegisterMessage(LockstepToStringRequest)

LockstepToStringResponse = _reflection.GeneratedProtocolMessageType('LockstepToStringResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPTOSTRINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepToStringResponse)
  })
_sym_db.RegisterMessage(LockstepToStringResponse)

OscilloscopeAddChannelRequest = _reflection.GeneratedProtocolMessageType('OscilloscopeAddChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPEADDCHANNELREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeAddChannelRequest)
  })
_sym_db.RegisterMessage(OscilloscopeAddChannelRequest)

OscilloscopeClearChannelsRequest = _reflection.GeneratedProtocolMessageType('OscilloscopeClearChannelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPECLEARCHANNELSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeClearChannelsRequest)
  })
_sym_db.RegisterMessage(OscilloscopeClearChannelsRequest)

OscilloscopeStartStopRequest = _reflection.GeneratedProtocolMessageType('OscilloscopeStartStopRequest', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPESTARTSTOPREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeStartStopRequest)
  })
_sym_db.RegisterMessage(OscilloscopeStartStopRequest)

OscilloscopeReadRequest = _reflection.GeneratedProtocolMessageType('OscilloscopeReadRequest', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPEREADREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeReadRequest)
  })
_sym_db.RegisterMessage(OscilloscopeReadRequest)

OscilloscopeReadResponse = _reflection.GeneratedProtocolMessageType('OscilloscopeReadResponse', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPEREADRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeReadResponse)
  })
_sym_db.RegisterMessage(OscilloscopeReadResponse)

OscilloscopeDataIdentifier = _reflection.GeneratedProtocolMessageType('OscilloscopeDataIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPEDATAIDENTIFIER,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeDataIdentifier)
  })
_sym_db.RegisterMessage(OscilloscopeDataIdentifier)

OscilloscopeCaptureProperties = _reflection.GeneratedProtocolMessageType('OscilloscopeCaptureProperties', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPECAPTUREPROPERTIES,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeCaptureProperties)
  })
_sym_db.RegisterMessage(OscilloscopeCaptureProperties)

OscilloscopeDataGetPropertiesResponse = _reflection.GeneratedProtocolMessageType('OscilloscopeDataGetPropertiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPEDATAGETPROPERTIESRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeDataGetPropertiesResponse)
  })
_sym_db.RegisterMessage(OscilloscopeDataGetPropertiesResponse)

OscilloscopeDataGetSavedSettingRequest = _reflection.GeneratedProtocolMessageType('OscilloscopeDataGetSavedSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPEDATAGETSAVEDSETTINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeDataGetSavedSettingRequest)
  })
_sym_db.RegisterMessage(OscilloscopeDataGetSavedSettingRequest)

OscilloscopeDataGetSavedSettingResponse = _reflection.GeneratedProtocolMessageType('OscilloscopeDataGetSavedSettingResponse', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPEDATAGETSAVEDSETTINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeDataGetSavedSettingResponse)
  })
_sym_db.RegisterMessage(OscilloscopeDataGetSavedSettingResponse)

OscilloscopeDataGetSampleTimeRequest = _reflection.GeneratedProtocolMessageType('OscilloscopeDataGetSampleTimeRequest', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPEDATAGETSAMPLETIMEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeDataGetSampleTimeRequest)
  })
_sym_db.RegisterMessage(OscilloscopeDataGetSampleTimeRequest)

OscilloscopeDataGetSamplesRequest = _reflection.GeneratedProtocolMessageType('OscilloscopeDataGetSamplesRequest', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPEDATAGETSAMPLESREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeDataGetSamplesRequest)
  })
_sym_db.RegisterMessage(OscilloscopeDataGetSamplesRequest)

OscilloscopeDataGetSamplesResponse = _reflection.GeneratedProtocolMessageType('OscilloscopeDataGetSamplesResponse', (_message.Message,), {
  'DESCRIPTOR' : _OSCILLOSCOPEDATAGETSAMPLESRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OscilloscopeDataGetSamplesResponse)
  })
_sym_db.RegisterMessage(OscilloscopeDataGetSamplesResponse)

StreamSetupLiveRequest = _reflection.GeneratedProtocolMessageType('StreamSetupLiveRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETUPLIVEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetupLiveRequest)
  })
_sym_db.RegisterMessage(StreamSetupLiveRequest)

StreamSetupLiveCompositeRequest = _reflection.GeneratedProtocolMessageType('StreamSetupLiveCompositeRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETUPLIVECOMPOSITEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetupLiveCompositeRequest)
  })
_sym_db.RegisterMessage(StreamSetupLiveCompositeRequest)

StreamSetupStoreRequest = _reflection.GeneratedProtocolMessageType('StreamSetupStoreRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETUPSTOREREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetupStoreRequest)
  })
_sym_db.RegisterMessage(StreamSetupStoreRequest)

StreamSetupStoreCompositeRequest = _reflection.GeneratedProtocolMessageType('StreamSetupStoreCompositeRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETUPSTORECOMPOSITEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetupStoreCompositeRequest)
  })
_sym_db.RegisterMessage(StreamSetupStoreCompositeRequest)

StreamSetupStoreArbitraryAxesRequest = _reflection.GeneratedProtocolMessageType('StreamSetupStoreArbitraryAxesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETUPSTOREARBITRARYAXESREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetupStoreArbitraryAxesRequest)
  })
_sym_db.RegisterMessage(StreamSetupStoreArbitraryAxesRequest)

StreamCallRequest = _reflection.GeneratedProtocolMessageType('StreamCallRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCALLREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamCallRequest)
  })
_sym_db.RegisterMessage(StreamCallRequest)

StreamLineRequest = _reflection.GeneratedProtocolMessageType('StreamLineRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMLINEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamLineRequest)
  })
_sym_db.RegisterMessage(StreamLineRequest)

StreamArcRequest = _reflection.GeneratedProtocolMessageType('StreamArcRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMARCREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamArcRequest)
  })
_sym_db.RegisterMessage(StreamArcRequest)

StreamCircleRequest = _reflection.GeneratedProtocolMessageType('StreamCircleRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCIRCLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamCircleRequest)
  })
_sym_db.RegisterMessage(StreamCircleRequest)

StreamWaitDigitalInputRequest = _reflection.GeneratedProtocolMessageType('StreamWaitDigitalInputRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMWAITDIGITALINPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamWaitDigitalInputRequest)
  })
_sym_db.RegisterMessage(StreamWaitDigitalInputRequest)

StreamWaitAnalogInputRequest = _reflection.GeneratedProtocolMessageType('StreamWaitAnalogInputRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMWAITANALOGINPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamWaitAnalogInputRequest)
  })
_sym_db.RegisterMessage(StreamWaitAnalogInputRequest)

StreamSetDigitalOutputRequest = _reflection.GeneratedProtocolMessageType('StreamSetDigitalOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETDIGITALOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetDigitalOutputRequest)
  })
_sym_db.RegisterMessage(StreamSetDigitalOutputRequest)

StreamSetAnalogOutputRequest = _reflection.GeneratedProtocolMessageType('StreamSetAnalogOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETANALOGOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetAnalogOutputRequest)
  })
_sym_db.RegisterMessage(StreamSetAnalogOutputRequest)

StreamToggleDigitalOutputRequest = _reflection.GeneratedProtocolMessageType('StreamToggleDigitalOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTOGGLEDIGITALOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamToggleDigitalOutputRequest)
  })
_sym_db.RegisterMessage(StreamToggleDigitalOutputRequest)

StreamSetAllDigitalOutputsRequest = _reflection.GeneratedProtocolMessageType('StreamSetAllDigitalOutputsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETALLDIGITALOUTPUTSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetAllDigitalOutputsRequest)
  })
_sym_db.RegisterMessage(StreamSetAllDigitalOutputsRequest)

StreamSetAllAnalogOutputsRequest = _reflection.GeneratedProtocolMessageType('StreamSetAllAnalogOutputsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETALLANALOGOUTPUTSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetAllAnalogOutputsRequest)
  })
_sym_db.RegisterMessage(StreamSetAllAnalogOutputsRequest)

StreamWaitRequest = _reflection.GeneratedProtocolMessageType('StreamWaitRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMWAITREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamWaitRequest)
  })
_sym_db.RegisterMessage(StreamWaitRequest)

StreamWaitUntilIdleRequest = _reflection.GeneratedProtocolMessageType('StreamWaitUntilIdleRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMWAITUNTILIDLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamWaitUntilIdleRequest)
  })
_sym_db.RegisterMessage(StreamWaitUntilIdleRequest)

StreamCorkRequest = _reflection.GeneratedProtocolMessageType('StreamCorkRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCORKREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamCorkRequest)
  })
_sym_db.RegisterMessage(StreamCorkRequest)

StreamUncorkRequest = _reflection.GeneratedProtocolMessageType('StreamUncorkRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMUNCORKREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamUncorkRequest)
  })
_sym_db.RegisterMessage(StreamUncorkRequest)

StreamIsBusyRequest = _reflection.GeneratedProtocolMessageType('StreamIsBusyRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMISBUSYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamIsBusyRequest)
  })
_sym_db.RegisterMessage(StreamIsBusyRequest)

StreamIsBusyResponse = _reflection.GeneratedProtocolMessageType('StreamIsBusyResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMISBUSYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamIsBusyResponse)
  })
_sym_db.RegisterMessage(StreamIsBusyResponse)

StreamGetAxesRequest = _reflection.GeneratedProtocolMessageType('StreamGetAxesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETAXESREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetAxesRequest)
  })
_sym_db.RegisterMessage(StreamGetAxesRequest)

StreamGetAxesResponse = _reflection.GeneratedProtocolMessageType('StreamGetAxesResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETAXESRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetAxesResponse)
  })
_sym_db.RegisterMessage(StreamGetAxesResponse)

StreamGetModeRequest = _reflection.GeneratedProtocolMessageType('StreamGetModeRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMODEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetModeRequest)
  })
_sym_db.RegisterMessage(StreamGetModeRequest)

StreamGetModeResponse = _reflection.GeneratedProtocolMessageType('StreamGetModeResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMODERESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetModeResponse)
  })
_sym_db.RegisterMessage(StreamGetModeResponse)

StreamGetMaxSpeedRequest = _reflection.GeneratedProtocolMessageType('StreamGetMaxSpeedRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXSPEEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxSpeedRequest)
  })
_sym_db.RegisterMessage(StreamGetMaxSpeedRequest)

StreamGetMaxSpeedResponse = _reflection.GeneratedProtocolMessageType('StreamGetMaxSpeedResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXSPEEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxSpeedResponse)
  })
_sym_db.RegisterMessage(StreamGetMaxSpeedResponse)

StreamSetMaxSpeedRequest = _reflection.GeneratedProtocolMessageType('StreamSetMaxSpeedRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETMAXSPEEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetMaxSpeedRequest)
  })
_sym_db.RegisterMessage(StreamSetMaxSpeedRequest)

StreamGetMaxTangentialAccelerationRequest = _reflection.GeneratedProtocolMessageType('StreamGetMaxTangentialAccelerationRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXTANGENTIALACCELERATIONREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxTangentialAccelerationRequest)
  })
_sym_db.RegisterMessage(StreamGetMaxTangentialAccelerationRequest)

StreamGetMaxTangentialAccelerationResponse = _reflection.GeneratedProtocolMessageType('StreamGetMaxTangentialAccelerationResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXTANGENTIALACCELERATIONRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxTangentialAccelerationResponse)
  })
_sym_db.RegisterMessage(StreamGetMaxTangentialAccelerationResponse)

StreamSetMaxTangentialAccelerationRequest = _reflection.GeneratedProtocolMessageType('StreamSetMaxTangentialAccelerationRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETMAXTANGENTIALACCELERATIONREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetMaxTangentialAccelerationRequest)
  })
_sym_db.RegisterMessage(StreamSetMaxTangentialAccelerationRequest)

StreamGetMaxCentripetalAccelerationRequest = _reflection.GeneratedProtocolMessageType('StreamGetMaxCentripetalAccelerationRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXCENTRIPETALACCELERATIONREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxCentripetalAccelerationRequest)
  })
_sym_db.RegisterMessage(StreamGetMaxCentripetalAccelerationRequest)

StreamGetMaxCentripetalAccelerationResponse = _reflection.GeneratedProtocolMessageType('StreamGetMaxCentripetalAccelerationResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXCENTRIPETALACCELERATIONRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxCentripetalAccelerationResponse)
  })
_sym_db.RegisterMessage(StreamGetMaxCentripetalAccelerationResponse)

StreamSetMaxCentripetalAccelerationRequest = _reflection.GeneratedProtocolMessageType('StreamSetMaxCentripetalAccelerationRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETMAXCENTRIPETALACCELERATIONREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetMaxCentripetalAccelerationRequest)
  })
_sym_db.RegisterMessage(StreamSetMaxCentripetalAccelerationRequest)

StreamToStringRequest = _reflection.GeneratedProtocolMessageType('StreamToStringRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTOSTRINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamToStringRequest)
  })
_sym_db.RegisterMessage(StreamToStringRequest)

StreamToStringResponse = _reflection.GeneratedProtocolMessageType('StreamToStringResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTOSTRINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamToStringResponse)
  })
_sym_db.RegisterMessage(StreamToStringResponse)

StreamDisableRequest = _reflection.GeneratedProtocolMessageType('StreamDisableRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMDISABLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamDisableRequest)
  })
_sym_db.RegisterMessage(StreamDisableRequest)

StreamBufferGetContentRequest = _reflection.GeneratedProtocolMessageType('StreamBufferGetContentRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBUFFERGETCONTENTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamBufferGetContentRequest)
  })
_sym_db.RegisterMessage(StreamBufferGetContentRequest)

StreamBufferGetContentResponse = _reflection.GeneratedProtocolMessageType('StreamBufferGetContentResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBUFFERGETCONTENTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamBufferGetContentResponse)
  })
_sym_db.RegisterMessage(StreamBufferGetContentResponse)

StreamBufferEraseRequest = _reflection.GeneratedProtocolMessageType('StreamBufferEraseRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBUFFERERASEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamBufferEraseRequest)
  })
_sym_db.RegisterMessage(StreamBufferEraseRequest)

StreamGenericCommandRequest = _reflection.GeneratedProtocolMessageType('StreamGenericCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGENERICCOMMANDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGenericCommandRequest)
  })
_sym_db.RegisterMessage(StreamGenericCommandRequest)

StreamGenericCommandBatchRequest = _reflection.GeneratedProtocolMessageType('StreamGenericCommandBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGENERICCOMMANDBATCHREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGenericCommandBatchRequest)
  })
_sym_db.RegisterMessage(StreamGenericCommandBatchRequest)

BinaryReplyOnlyEvent = _reflection.GeneratedProtocolMessageType('BinaryReplyOnlyEvent', (_message.Message,), {
  'DESCRIPTOR' : _BINARYREPLYONLYEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryReplyOnlyEvent)
  })
_sym_db.RegisterMessage(BinaryReplyOnlyEvent)

OpenBinaryInterfaceRequest = _reflection.GeneratedProtocolMessageType('OpenBinaryInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _OPENBINARYINTERFACEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OpenBinaryInterfaceRequest)
  })
_sym_db.RegisterMessage(OpenBinaryInterfaceRequest)

UnknownBinaryResponseEvent = _reflection.GeneratedProtocolMessageType('UnknownBinaryResponseEvent', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNBINARYRESPONSEEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.UnknownBinaryResponseEvent)
  })
_sym_db.RegisterMessage(UnknownBinaryResponseEvent)

GenericBinaryRequest = _reflection.GeneratedProtocolMessageType('GenericBinaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERICBINARYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GenericBinaryRequest)
  })
_sym_db.RegisterMessage(GenericBinaryRequest)

BinaryMessage = _reflection.GeneratedProtocolMessageType('BinaryMessage', (_message.Message,), {
  'DESCRIPTOR' : _BINARYMESSAGE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryMessage)
  })
_sym_db.RegisterMessage(BinaryMessage)

BinaryMessageCollection = _reflection.GeneratedProtocolMessageType('BinaryMessageCollection', (_message.Message,), {
  'DESCRIPTOR' : _BINARYMESSAGECOLLECTION,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryMessageCollection)
  })
_sym_db.RegisterMessage(BinaryMessageCollection)

BinaryDeviceRenumberRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceRenumberRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICERENUMBERREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceRenumberRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceRenumberRequest)

BinaryDeviceRenumberResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceRenumberResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICERENUMBERRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceRenumberResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceRenumberResponse)

BinaryDeviceIdentifyRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceIdentifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEIDENTIFYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceIdentifyRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceIdentifyRequest)

BinaryDeviceIdentity = _reflection.GeneratedProtocolMessageType('BinaryDeviceIdentity', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEIDENTITY,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceIdentity)
  })
_sym_db.RegisterMessage(BinaryDeviceIdentity)

BinaryDeviceGetIdentityRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetIdentityRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETIDENTITYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetIdentityRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceGetIdentityRequest)

BinaryDeviceGetIdentityResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetIdentityResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETIDENTITYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetIdentityResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceGetIdentityResponse)

BinaryDeviceGetIsIdentifiedRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetIsIdentifiedRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETISIDENTIFIEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetIsIdentifiedRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceGetIsIdentifiedRequest)

BinaryDeviceGetIsIdentifiedResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetIsIdentifiedResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETISIDENTIFIEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetIsIdentifiedResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceGetIsIdentifiedResponse)

BinaryGenericWithUnitsRequest = _reflection.GeneratedProtocolMessageType('BinaryGenericWithUnitsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYGENERICWITHUNITSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryGenericWithUnitsRequest)
  })
_sym_db.RegisterMessage(BinaryGenericWithUnitsRequest)

BinaryGenericWithUnitsResponse = _reflection.GeneratedProtocolMessageType('BinaryGenericWithUnitsResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYGENERICWITHUNITSRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryGenericWithUnitsResponse)
  })
_sym_db.RegisterMessage(BinaryGenericWithUnitsResponse)

BinaryDeviceHomeRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceHomeRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEHOMEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceHomeRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceHomeRequest)

BinaryDeviceMovementResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceMovementResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEMOVEMENTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceMovementResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceMovementResponse)

BinaryDeviceMoveRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceMoveRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEMOVEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceMoveRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceMoveRequest)

BinaryDeviceStopRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceStopRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICESTOPREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceStopRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceStopRequest)

BinaryDeviceWaitUntilIdleRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceWaitUntilIdleRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEWAITUNTILIDLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceWaitUntilIdleRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceWaitUntilIdleRequest)

BinaryDeviceIsBusyRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceIsBusyRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEISBUSYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceIsBusyRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceIsBusyRequest)

BinaryDeviceIsBusyResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceIsBusyResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEISBUSYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceIsBusyResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceIsBusyResponse)

BinaryDeviceDetectRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceDetectRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEDETECTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceDetectRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceDetectRequest)

BinaryDeviceDetectResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceDetectResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEDETECTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceDetectResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceDetectResponse)

BinaryDeviceGetSettingRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETSETTINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetSettingRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceGetSettingRequest)

BinaryDeviceGetSettingResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetSettingResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETSETTINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetSettingResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceGetSettingResponse)

BinaryDeviceSetSettingRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceSetSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICESETSETTINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceSetSettingRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceSetSettingRequest)

BinaryDeviceParkRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceParkRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEPARKREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceParkRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceParkRequest)

BinaryDeviceParkResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceParkResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEPARKRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceParkResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceParkResponse)

CustomInterfaceReadRequest = _reflection.GeneratedProtocolMessageType('CustomInterfaceReadRequest', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMINTERFACEREADREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CustomInterfaceReadRequest)
  })
_sym_db.RegisterMessage(CustomInterfaceReadRequest)

CustomInterfaceReadResponse = _reflection.GeneratedProtocolMessageType('CustomInterfaceReadResponse', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMINTERFACEREADRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CustomInterfaceReadResponse)
  })
_sym_db.RegisterMessage(CustomInterfaceReadResponse)

CustomInterfaceWriteRequest = _reflection.GeneratedProtocolMessageType('CustomInterfaceWriteRequest', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMINTERFACEWRITEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CustomInterfaceWriteRequest)
  })
_sym_db.RegisterMessage(CustomInterfaceWriteRequest)

CustomInterfaceOpenResponse = _reflection.GeneratedProtocolMessageType('CustomInterfaceOpenResponse', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMINTERFACEOPENRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CustomInterfaceOpenResponse)
  })
_sym_db.RegisterMessage(CustomInterfaceOpenResponse)

CustomInterfaceCloseRequest = _reflection.GeneratedProtocolMessageType('CustomInterfaceCloseRequest', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMINTERFACECLOSEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CustomInterfaceCloseRequest)
  })
_sym_db.RegisterMessage(CustomInterfaceCloseRequest)

GetStateRequest = _reflection.GeneratedProtocolMessageType('GetStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GetStateRequest)
  })
_sym_db.RegisterMessage(GetStateRequest)

GetStateResponse = _reflection.GeneratedProtocolMessageType('GetStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATERESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GetStateResponse)
  })
_sym_db.RegisterMessage(GetStateResponse)

CanSetStateRequest = _reflection.GeneratedProtocolMessageType('CanSetStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANSETSTATEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CanSetStateRequest)
  })
_sym_db.RegisterMessage(CanSetStateRequest)

CanSetStateAxisResponse = _reflection.GeneratedProtocolMessageType('CanSetStateAxisResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANSETSTATEAXISRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CanSetStateAxisResponse)
  })
_sym_db.RegisterMessage(CanSetStateAxisResponse)

CanSetStateDeviceResponse = _reflection.GeneratedProtocolMessageType('CanSetStateDeviceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANSETSTATEDEVICERESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CanSetStateDeviceResponse)
  })
_sym_db.RegisterMessage(CanSetStateDeviceResponse)

SetStateRequest = _reflection.GeneratedProtocolMessageType('SetStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSTATEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetStateRequest)
  })
_sym_db.RegisterMessage(SetStateRequest)

ServoTuningRequest = _reflection.GeneratedProtocolMessageType('ServoTuningRequest', (_message.Message,), {
  'DESCRIPTOR' : _SERVOTUNINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ServoTuningRequest)
  })
_sym_db.RegisterMessage(ServoTuningRequest)

ServoTuningParam = _reflection.GeneratedProtocolMessageType('ServoTuningParam', (_message.Message,), {
  'DESCRIPTOR' : _SERVOTUNINGPARAM,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ServoTuningParam)
  })
_sym_db.RegisterMessage(ServoTuningParam)

ParamsetInfo = _reflection.GeneratedProtocolMessageType('ParamsetInfo', (_message.Message,), {
  'DESCRIPTOR' : _PARAMSETINFO,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ParamsetInfo)
  })
_sym_db.RegisterMessage(ParamsetInfo)

SetServoTuningRequest = _reflection.GeneratedProtocolMessageType('SetServoTuningRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSERVOTUNINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetServoTuningRequest)
  })
_sym_db.RegisterMessage(SetServoTuningRequest)

GetStartupParamset = _reflection.GeneratedProtocolMessageType('GetStartupParamset', (_message.Message,), {
  'DESCRIPTOR' : _GETSTARTUPPARAMSET,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GetStartupParamset)
  })
_sym_db.RegisterMessage(GetStartupParamset)

StartupParamset = _reflection.GeneratedProtocolMessageType('StartupParamset', (_message.Message,), {
  'DESCRIPTOR' : _STARTUPPARAMSET,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StartupParamset)
  })
_sym_db.RegisterMessage(StartupParamset)

LoadParamset = _reflection.GeneratedProtocolMessageType('LoadParamset', (_message.Message,), {
  'DESCRIPTOR' : _LOADPARAMSET,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LoadParamset)
  })
_sym_db.RegisterMessage(LoadParamset)

SetServoTuningPIDRequest = _reflection.GeneratedProtocolMessageType('SetServoTuningPIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSERVOTUNINGPIDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetServoTuningPIDRequest)
  })
_sym_db.RegisterMessage(SetServoTuningPIDRequest)

PidTuning = _reflection.GeneratedProtocolMessageType('PidTuning', (_message.Message,), {
  'DESCRIPTOR' : _PIDTUNING,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.PidTuning)
  })
_sym_db.RegisterMessage(PidTuning)

GetSimpleTuningParamListRequest = _reflection.GeneratedProtocolMessageType('GetSimpleTuningParamListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSIMPLETUNINGPARAMLISTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GetSimpleTuningParamListRequest)
  })
_sym_db.RegisterMessage(GetSimpleTuningParamListRequest)

SetSimpleTuning = _reflection.GeneratedProtocolMessageType('SetSimpleTuning', (_message.Message,), {
  'DESCRIPTOR' : _SETSIMPLETUNING,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetSimpleTuning)
  })
_sym_db.RegisterMessage(SetSimpleTuning)

SimpleTuningParam = _reflection.GeneratedProtocolMessageType('SimpleTuningParam', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLETUNINGPARAM,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SimpleTuningParam)
  })
_sym_db.RegisterMessage(SimpleTuningParam)

SimpleTuningParamList = _reflection.GeneratedProtocolMessageType('SimpleTuningParamList', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLETUNINGPARAMLIST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SimpleTuningParamList)
  })
_sym_db.RegisterMessage(SimpleTuningParamList)

TranslatorCreateRequest = _reflection.GeneratedProtocolMessageType('TranslatorCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORCREATEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorCreateRequest)
  })
_sym_db.RegisterMessage(TranslatorCreateRequest)

TranslatorCreateResponse = _reflection.GeneratedProtocolMessageType('TranslatorCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORCREATERESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorCreateResponse)
  })
_sym_db.RegisterMessage(TranslatorCreateResponse)

TranslatorAxisDefinition = _reflection.GeneratedProtocolMessageType('TranslatorAxisDefinition', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORAXISDEFINITION,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorAxisDefinition)
  })
_sym_db.RegisterMessage(TranslatorAxisDefinition)

TranslatorDefinition = _reflection.GeneratedProtocolMessageType('TranslatorDefinition', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORDEFINITION,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorDefinition)
  })
_sym_db.RegisterMessage(TranslatorDefinition)

TranslatorConfig = _reflection.GeneratedProtocolMessageType('TranslatorConfig', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORCONFIG,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorConfig)
  })
_sym_db.RegisterMessage(TranslatorConfig)

TranslatorAxisMapping = _reflection.GeneratedProtocolMessageType('TranslatorAxisMapping', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORAXISMAPPING,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorAxisMapping)
  })
_sym_db.RegisterMessage(TranslatorAxisMapping)

TranslatorAxisTransformation = _reflection.GeneratedProtocolMessageType('TranslatorAxisTransformation', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORAXISTRANSFORMATION,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorAxisTransformation)
  })
_sym_db.RegisterMessage(TranslatorAxisTransformation)

TranslatorTranslateRequest = _reflection.GeneratedProtocolMessageType('TranslatorTranslateRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORTRANSLATEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorTranslateRequest)
  })
_sym_db.RegisterMessage(TranslatorTranslateRequest)

TranslateMessage = _reflection.GeneratedProtocolMessageType('TranslateMessage', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATEMESSAGE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslateMessage)
  })
_sym_db.RegisterMessage(TranslateMessage)

TranslatorTranslateResponse = _reflection.GeneratedProtocolMessageType('TranslatorTranslateResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORTRANSLATERESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorTranslateResponse)
  })
_sym_db.RegisterMessage(TranslatorTranslateResponse)

GCodeSyntaxExceptionData = _reflection.GeneratedProtocolMessageType('GCodeSyntaxExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _GCODESYNTAXEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GCodeSyntaxExceptionData)
  })
_sym_db.RegisterMessage(GCodeSyntaxExceptionData)

GCodeExecutionExceptionData = _reflection.GeneratedProtocolMessageType('GCodeExecutionExceptionData', (_message.Message,), {
  'DESCRIPTOR' : _GCODEEXECUTIONEXCEPTIONDATA,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GCodeExecutionExceptionData)
  })
_sym_db.RegisterMessage(GCodeExecutionExceptionData)

TranslatorFlushLiveRequest = _reflection.GeneratedProtocolMessageType('TranslatorFlushLiveRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORFLUSHLIVEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorFlushLiveRequest)
  })
_sym_db.RegisterMessage(TranslatorFlushLiveRequest)

TranslatorFlushResponse = _reflection.GeneratedProtocolMessageType('TranslatorFlushResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORFLUSHRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorFlushResponse)
  })
_sym_db.RegisterMessage(TranslatorFlushResponse)

TranslatorCreateLiveRequest = _reflection.GeneratedProtocolMessageType('TranslatorCreateLiveRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORCREATELIVEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorCreateLiveRequest)
  })
_sym_db.RegisterMessage(TranslatorCreateLiveRequest)

TranslatorEmptyRequest = _reflection.GeneratedProtocolMessageType('TranslatorEmptyRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATOREMPTYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorEmptyRequest)
  })
_sym_db.RegisterMessage(TranslatorEmptyRequest)

TranslatorSetTraverseRateRequest = _reflection.GeneratedProtocolMessageType('TranslatorSetTraverseRateRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORSETTRAVERSERATEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorSetTraverseRateRequest)
  })
_sym_db.RegisterMessage(TranslatorSetTraverseRateRequest)

TranslatorSetAxisPositionRequest = _reflection.GeneratedProtocolMessageType('TranslatorSetAxisPositionRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORSETAXISPOSITIONREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorSetAxisPositionRequest)
  })
_sym_db.RegisterMessage(TranslatorSetAxisPositionRequest)

TranslatorGetAxisPositionRequest = _reflection.GeneratedProtocolMessageType('TranslatorGetAxisPositionRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORGETAXISPOSITIONREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorGetAxisPositionRequest)
  })
_sym_db.RegisterMessage(TranslatorGetAxisPositionRequest)

TranslatorGetAxisPositionResponse = _reflection.GeneratedProtocolMessageType('TranslatorGetAxisPositionResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORGETAXISPOSITIONRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorGetAxisPositionResponse)
  })
_sym_db.RegisterMessage(TranslatorGetAxisPositionResponse)

TranslatorGetAxisOffsetRequest = _reflection.GeneratedProtocolMessageType('TranslatorGetAxisOffsetRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORGETAXISOFFSETREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorGetAxisOffsetRequest)
  })
_sym_db.RegisterMessage(TranslatorGetAxisOffsetRequest)

TranslatorGetCurrentCoordinateSystemResponse = _reflection.GeneratedProtocolMessageType('TranslatorGetCurrentCoordinateSystemResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORGETCURRENTCOORDINATESYSTEMRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorGetCurrentCoordinateSystemResponse)
  })
_sym_db.RegisterMessage(TranslatorGetCurrentCoordinateSystemResponse)

TranslatorSetFeedRateOverrideRequest = _reflection.GeneratedProtocolMessageType('TranslatorSetFeedRateOverrideRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATORSETFEEDRATEOVERRIDEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TranslatorSetFeedRateOverrideRequest)
  })
_sym_db.RegisterMessage(TranslatorSetFeedRateOverrideRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"./protobufs;zaber_motion_protobufs'
  _MESSAGETYPE._serialized_start=23238
  _MESSAGETYPE._serialized_end=23283
  _ERRORS._serialized_start=23286
  _ERRORS._serialized_end=24257
  _INTERFACETYPE._serialized_start=24259
  _INTERFACETYPE._serialized_end=24340
  _REQUEST._serialized_start=48
  _REQUEST._serialized_end=74
  _RESPONSE._serialized_start=77
  _RESPONSE._serialized_end=262
  _RESPONSE_RESPONSETYPE._serialized_start=229
  _RESPONSE_RESPONSETYPE._serialized_end=262
  _EVENT._serialized_start=264
  _EVENT._serialized_end=286
  _EMPTYREQUEST._serialized_start=288
  _EMPTYREQUEST._serialized_end=302
  _AXISIDENTITY._serialized_start=305
  _AXISIDENTITY._serialized_end=526
  _AXISIDENTITY_AXISTYPE._serialized_start=479
  _AXISIDENTITY_AXISTYPE._serialized_end=526
  _DEVICEIDENTITY._serialized_start=529
  _DEVICEIDENTITY._serialized_end=732
  _FIRMWAREVERSION._serialized_start=734
  _FIRMWAREVERSION._serialized_end=796
  _DEVICEIOINFO._serialized_start=799
  _DEVICEIOINFO._serialized_end=937
  _MEASUREMENT._serialized_start=939
  _MEASUREMENT._serialized_end=981
  _STREAMAXISDEFINITION._serialized_start=983
  _STREAMAXISDEFINITION._serialized_end=1045
  _INVALIDPACKETEXCEPTIONDATA._serialized_start=1047
  _INVALIDPACKETEXCEPTIONDATA._serialized_end=1107
  _DEVICEADDRESSCONFLICTEXCEPTIONDATA._serialized_start=1109
  _DEVICEADDRESSCONFLICTEXCEPTIONDATA._serialized_end=1171
  _MOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_start=1173
  _MOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_end=1241
  _STREAMMOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_start=1243
  _STREAMMOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_end=1317
  _MOVEMENTFAILEDEXCEPTIONDATA._serialized_start=1319
  _MOVEMENTFAILEDEXCEPTIONDATA._serialized_end=1382
  _STREAMMOVEMENTFAILEDEXCEPTIONDATA._serialized_start=1384
  _STREAMMOVEMENTFAILEDEXCEPTIONDATA._serialized_end=1453
  _STREAMEXECUTIONEXCEPTIONDATA._serialized_start=1455
  _STREAMEXECUTIONEXCEPTIONDATA._serialized_end=1521
  _INVALIDRESPONSEEXCEPTIONDATA._serialized_start=1523
  _INVALIDRESPONSEEXCEPTIONDATA._serialized_end=1571
  _COMMANDFAILEDEXCEPTIONDATA._serialized_start=1573
  _COMMANDFAILEDEXCEPTIONDATA._serialized_end=1682
  _BINARYCOMMANDFAILEDEXCEPTIONDATA._serialized_start=1684
  _BINARYCOMMANDFAILEDEXCEPTIONDATA._serialized_end=1741
  _SETPERIPHERALSTATEEXCEPTIONDATA._serialized_start=1743
  _SETPERIPHERALSTATEEXCEPTIONDATA._serialized_end=1854
  _SETDEVICESTATEEXCEPTIONDATA._serialized_start=1857
  _SETDEVICESTATEEXCEPTIONDATA._serialized_end=2082
  _TESTREQUEST._serialized_start=2084
  _TESTREQUEST._serialized_end=2170
  _TESTRESPONSE._serialized_start=2172
  _TESTRESPONSE._serialized_end=2205
  _TESTRESPONSELONG._serialized_start=2207
  _TESTRESPONSELONG._serialized_end=2244
  _TESTEVENT._serialized_start=2246
  _TESTEVENT._serialized_end=2271
  _TOOLSLISTSERIALPORTSRESPONSE._serialized_start=2273
  _TOOLSLISTSERIALPORTSRESPONSE._serialized_end=2318
  _GETMESSAGEROUTERPIPERESPONSE._serialized_start=2320
  _GETMESSAGEROUTERPIPERESPONSE._serialized_end=2365
  _SETDEVICEDBSOURCEREQUEST._serialized_start=2367
  _SETDEVICEDBSOURCEREQUEST._serialized_end=2440
  _TOGGLEDEVICEDBSTOREREQUEST._serialized_start=2442
  _TOGGLEDEVICEDBSTOREREQUEST._serialized_end=2513
  _OPENINTERFACEREQUEST._serialized_start=2516
  _OPENINTERFACEREQUEST._serialized_end=2811
  _OPENINTERFACERESPONSE._serialized_start=2813
  _OPENINTERFACERESPONSE._serialized_end=2858
  _CLOSEINTERFACEREQUEST._serialized_start=2860
  _CLOSEINTERFACEREQUEST._serialized_end=2905
  _EMPTYINTERFACEREQUEST._serialized_start=2907
  _EMPTYINTERFACEREQUEST._serialized_end=2952
  _GETINTERFACETIMEOUTRESPONSE._serialized_start=2954
  _GETINTERFACETIMEOUTRESPONSE._serialized_end=2998
  _SETINTERFACETIMEOUTREQUEST._serialized_start=3000
  _SETINTERFACETIMEOUTREQUEST._serialized_end=3067
  _GETINTERFACECHECKSUMENABLEDRESPONSE._serialized_start=3069
  _GETINTERFACECHECKSUMENABLEDRESPONSE._serialized_end=3121
  _SETINTERFACECHECKSUMENABLEDREQUEST._serialized_start=3123
  _SETINTERFACECHECKSUMENABLEDREQUEST._serialized_end=3201
  _TOSTRINGREQUEST._serialized_start=3203
  _TOSTRINGREQUEST._serialized_end=3272
  _TOSTRINGRESPONSE._serialized_start=3274
  _TOSTRINGRESPONSE._serialized_end=3308
  _GENERICCOMMANDREQUEST._serialized_start=3311
  _GENERICCOMMANDREQUEST._serialized_end=3442
  _GENERICCOMMANDRESPONSE._serialized_start=3445
  _GENERICCOMMANDRESPONSE._serialized_end=3645
  _GENERICCOMMANDRESPONSECOLLECTION._serialized_start=3647
  _GENERICCOMMANDRESPONSECOLLECTION._serialized_end=3748
  _UNKNOWNRESPONSEEVENT._serialized_start=3751
  _UNKNOWNRESPONSEEVENT._serialized_end=3971
  _ALERTEVENT._serialized_start=3974
  _ALERTEVENT._serialized_end=4105
  _DISCONNECTEDEVENT._serialized_start=4107
  _DISCONNECTEDEVENT._serialized_end=4223
  _DEVICERENUMBERREQUEST._serialized_start=4225
  _DEVICERENUMBERREQUEST._serialized_end=4293
  _DEVICERENUMBERRESPONSE._serialized_start=4295
  _DEVICERENUMBERRESPONSE._serialized_end=4343
  _DEVICEDETECTREQUEST._serialized_start=4345
  _DEVICEDETECTREQUEST._serialized_end=4414
  _DEVICEDETECTRESPONSE._serialized_start=4416
  _DEVICEDETECTRESPONSE._serialized_end=4455
  _DEVICEHOMEREQUEST._serialized_start=4457
  _DEVICEHOMEREQUEST._serialized_end=4553
  _DEVICEWAITUNTILIDLEREQUEST._serialized_start=4555
  _DEVICEWAITUNTILIDLEREQUEST._serialized_end=4665
  _DEVICEMOVEREQUEST._serialized_start=4668
  _DEVICEMOVEREQUEST._serialized_end=4914
  _DEVICEMOVEREQUEST_MOVETYPE._serialized_start=4859
  _DEVICEMOVEREQUEST_MOVETYPE._serialized_end=4914
  _DEVICESTOPREQUEST._serialized_start=4916
  _DEVICESTOPREQUEST._serialized_end=5012
  _DEVICEIDENTIFYREQUEST._serialized_start=5014
  _DEVICEIDENTIFYREQUEST._serialized_end=5075
  _DEVICEONALLREQUEST._serialized_start=5077
  _DEVICEONALLREQUEST._serialized_end=5144
  _DEVICEONALLRESPONSE._serialized_start=5146
  _DEVICEONALLRESPONSE._serialized_end=5193
  _DEVICEGETIDENTITYREQUEST._serialized_start=5195
  _DEVICEGETIDENTITYREQUEST._serialized_end=5259
  _DEVICEGETIDENTITYRESPONSE._serialized_start=5261
  _DEVICEGETIDENTITYRESPONSE._serialized_end=5346
  _DEVICEGETISIDENTIFIEDREQUEST._serialized_start=5348
  _DEVICEGETISIDENTIFIEDREQUEST._serialized_end=5416
  _DEVICEGETISIDENTIFIEDRESPONSE._serialized_start=5418
  _DEVICEGETISIDENTIFIEDRESPONSE._serialized_end=5472
  _DEVICEGETAXISIDENTITYREQUEST._serialized_start=5474
  _DEVICEGETAXISIDENTITYREQUEST._serialized_end=5556
  _DEVICEGETAXISIDENTITYRESPONSE._serialized_start=5558
  _DEVICEGETAXISIDENTITYRESPONSE._serialized_end=5645
  _DEVICEISBUSYREQUEST._serialized_start=5647
  _DEVICEISBUSYREQUEST._serialized_end=5720
  _DEVICEISBUSYRESPONSE._serialized_start=5722
  _DEVICEISBUSYRESPONSE._serialized_end=5761
  _DEVICEGETWARNINGSREQUEST._serialized_start=5763
  _DEVICEGETWARNINGSREQUEST._serialized_end=5856
  _DEVICEGETWARNINGSRESPONSE._serialized_start=5858
  _DEVICEGETWARNINGSRESPONSE._serialized_end=5900
  _DEVICEGETALLDIGITALIOREQUEST._serialized_start=5902
  _DEVICEGETALLDIGITALIOREQUEST._serialized_end=5992
  _DEVICEGETALLDIGITALIORESPONSE._serialized_start=5994
  _DEVICEGETALLDIGITALIORESPONSE._serialized_end=6041
  _DEVICEGETALLANALOGIOREQUEST._serialized_start=6043
  _DEVICEGETALLANALOGIOREQUEST._serialized_end=6132
  _DEVICEGETALLANALOGIORESPONSE._serialized_start=6134
  _DEVICEGETALLANALOGIORESPONSE._serialized_end=6180
  _DEVICEGETDIGITALIOREQUEST._serialized_start=6182
  _DEVICEGETDIGITALIOREQUEST._serialized_end=6293
  _DEVICEGETDIGITALIORESPONSE._serialized_start=6295
  _DEVICEGETDIGITALIORESPONSE._serialized_end=6338
  _DEVICEGETANALOGIOREQUEST._serialized_start=6340
  _DEVICEGETANALOGIOREQUEST._serialized_end=6450
  _DEVICEGETANALOGIORESPONSE._serialized_start=6452
  _DEVICEGETANALOGIORESPONSE._serialized_end=6494
  _DEVICESETALLDIGITALOUTPUTSREQUEST._serialized_start=6496
  _DEVICESETALLDIGITALOUTPUTSREQUEST._serialized_end=6585
  _DEVICESETALLANALOGOUTPUTSREQUEST._serialized_start=6587
  _DEVICESETALLANALOGOUTPUTSREQUEST._serialized_end=6675
  _DEVICESETDIGITALOUTPUTREQUEST._serialized_start=6677
  _DEVICESETDIGITALOUTPUTREQUEST._serialized_end=6785
  _DEVICESETANALOGOUTPUTREQUEST._serialized_start=6787
  _DEVICESETANALOGOUTPUTREQUEST._serialized_end=6894
  _DEVICEGETIOCHANNELSINFOREQUEST._serialized_start=6896
  _DEVICEGETIOCHANNELSINFOREQUEST._serialized_end=6966
  _SETLOGOUTPUTREQUEST._serialized_start=6968
  _SETLOGOUTPUTREQUEST._serialized_end=7022
  _DEVICEGETSETTINGREQUEST._serialized_start=7024
  _DEVICEGETSETTINGREQUEST._serialized_end=7132
  _DEVICEGETSETTINGRESPONSE._serialized_start=7134
  _DEVICEGETSETTINGRESPONSE._serialized_end=7175
  _DEVICEGETSETTINGSTRRESPONSE._serialized_start=7177
  _DEVICEGETSETTINGSTRRESPONSE._serialized_end=7221
  _DEVICECONVERTSETTINGREQUEST._serialized_start=7224
  _DEVICECONVERTSETTINGREQUEST._serialized_end=7372
  _DEVICECONVERTSETTINGRESPONSE._serialized_start=7374
  _DEVICECONVERTSETTINGRESPONSE._serialized_end=7419
  _DEVICESETSETTINGREQUEST._serialized_start=7421
  _DEVICESETSETTINGREQUEST._serialized_end=7544
  _DEVICESETSETTINGSTRREQUEST._serialized_start=7546
  _DEVICESETSETTINGSTRREQUEST._serialized_end=7658
  _PREPARECOMMANDREQUEST._serialized_start=7661
  _PREPARECOMMANDREQUEST._serialized_end=7819
  _PREPARECOMMANDRESPONSE._serialized_start=7821
  _PREPARECOMMANDRESPONSE._serialized_end=7862
  _DEVICEPARKREQUEST._serialized_start=7864
  _DEVICEPARKREQUEST._serialized_end=7935
  _DEVICEISPARKEDRESPONSE._serialized_start=7937
  _DEVICEISPARKEDRESPONSE._serialized_end=7980
  _LOCKSTEPENABLEREQUEST._serialized_start=7982
  _LOCKSTEPENABLEREQUEST._serialized_end=8084
  _LOCKSTEPDISABLEREQUEST._serialized_start=8086
  _LOCKSTEPDISABLEREQUEST._serialized_end=8200
  _LOCKSTEPSTOPREQUEST._serialized_start=8202
  _LOCKSTEPSTOPREQUEST._serialized_end=8313
  _LOCKSTEPHOMEREQUEST._serialized_start=8315
  _LOCKSTEPHOMEREQUEST._serialized_end=8426
  _LOCKSTEPMOVEREQUEST._serialized_start=8429
  _LOCKSTEPMOVEREQUEST._serialized_end=8692
  _LOCKSTEPMOVEREQUEST_MOVETYPE._serialized_start=4859
  _LOCKSTEPMOVEREQUEST_MOVETYPE._serialized_end=4914
  _LOCKSTEPWAITUNTILIDLEREQUEST._serialized_start=8694
  _LOCKSTEPWAITUNTILIDLEREQUEST._serialized_end=8819
  _LOCKSTEPISBUSYREQUEST._serialized_start=8821
  _LOCKSTEPISBUSYREQUEST._serialized_end=8909
  _LOCKSTEPISBUSYRESPONSE._serialized_start=8911
  _LOCKSTEPISBUSYRESPONSE._serialized_end=8952
  _LOCKSTEPGETAXESREQUEST._serialized_start=8954
  _LOCKSTEPGETAXESREQUEST._serialized_end=9043
  _LOCKSTEPAXES._serialized_start=9045
  _LOCKSTEPAXES._serialized_end=9123
  _LOCKSTEPGETAXESRESPONSE._serialized_start=9125
  _LOCKSTEPGETAXESRESPONSE._serialized_end=9202
  _LOCKSTEPGETAXISNUMBERSREQUEST._serialized_start=9204
  _LOCKSTEPGETAXISNUMBERSREQUEST._serialized_end=9300
  _LOCKSTEPGETAXISNUMBERSRESPONSE._serialized_start=9302
  _LOCKSTEPGETAXISNUMBERSRESPONSE._serialized_end=9348
  _LOCKSTEPGETTWISTSREQUEST._serialized_start=9350
  _LOCKSTEPGETTWISTSREQUEST._serialized_end=9455
  _LOCKSTEPGETTWISTSRESPONSE._serialized_start=9457
  _LOCKSTEPGETTWISTSRESPONSE._serialized_end=9500
  _LOCKSTEPGETOFFSETSREQUEST._serialized_start=9502
  _LOCKSTEPGETOFFSETSREQUEST._serialized_end=9608
  _LOCKSTEPGETOFFSETSRESPONSE._serialized_start=9610
  _LOCKSTEPGETOFFSETSRESPONSE._serialized_end=9655
  _LOCKSTEPISENABLEDREQUEST._serialized_start=9657
  _LOCKSTEPISENABLEDREQUEST._serialized_end=9748
  _LOCKSTEPISENABLEDRESPONSE._serialized_start=9750
  _LOCKSTEPISENABLEDRESPONSE._serialized_end=9797
  _LOCKSTEPTOSTRINGREQUEST._serialized_start=9799
  _LOCKSTEPTOSTRINGREQUEST._serialized_end=9889
  _LOCKSTEPTOSTRINGRESPONSE._serialized_start=9891
  _LOCKSTEPTOSTRINGRESPONSE._serialized_end=9933
  _OSCILLOSCOPEADDCHANNELREQUEST._serialized_start=9935
  _OSCILLOSCOPEADDCHANNELREQUEST._serialized_end=10035
  _OSCILLOSCOPECLEARCHANNELSREQUEST._serialized_start=10037
  _OSCILLOSCOPECLEARCHANNELSREQUEST._serialized_end=10109
  _OSCILLOSCOPESTARTSTOPREQUEST._serialized_start=10111
  _OSCILLOSCOPESTARTSTOPREQUEST._serialized_end=10194
  _OSCILLOSCOPEREADREQUEST._serialized_start=10196
  _OSCILLOSCOPEREADREQUEST._serialized_end=10259
  _OSCILLOSCOPEREADRESPONSE._serialized_start=10261
  _OSCILLOSCOPEREADRESPONSE._serialized_end=10305
  _OSCILLOSCOPEDATAIDENTIFIER._serialized_start=10307
  _OSCILLOSCOPEDATAIDENTIFIER._serialized_end=10390
  _OSCILLOSCOPECAPTUREPROPERTIES._serialized_start=10392
  _OSCILLOSCOPECAPTUREPROPERTIES._serialized_end=10461
  _OSCILLOSCOPEDATAGETPROPERTIESRESPONSE._serialized_start=10463
  _OSCILLOSCOPEDATAGETPROPERTIESRESPONSE._serialized_end=10577
  _OSCILLOSCOPEDATAGETSAVEDSETTINGREQUEST._serialized_start=10579
  _OSCILLOSCOPEDATAGETSAVEDSETTINGREQUEST._serialized_end=10688
  _OSCILLOSCOPEDATAGETSAVEDSETTINGRESPONSE._serialized_start=10690
  _OSCILLOSCOPEDATAGETSAVEDSETTINGRESPONSE._serialized_end=10746
  _OSCILLOSCOPEDATAGETSAMPLETIMEREQUEST._serialized_start=10748
  _OSCILLOSCOPEDATAGETSAMPLETIMEREQUEST._serialized_end=10870
  _OSCILLOSCOPEDATAGETSAMPLESREQUEST._serialized_start=10872
  _OSCILLOSCOPEDATAGETSAMPLESREQUEST._serialized_end=10976
  _OSCILLOSCOPEDATAGETSAMPLESRESPONSE._serialized_start=10978
  _OSCILLOSCOPEDATAGETSAMPLESRESPONSE._serialized_end=11028
  _STREAMSETUPLIVEREQUEST._serialized_start=11030
  _STREAMSETUPLIVEREQUEST._serialized_end=11125
  _STREAMSETUPLIVECOMPOSITEREQUEST._serialized_start=11128
  _STREAMSETUPLIVECOMPOSITEREQUEST._serialized_end=11278
  _STREAMSETUPSTOREREQUEST._serialized_start=11280
  _STREAMSETUPSTOREREQUEST._serialized_end=11399
  _STREAMSETUPSTORECOMPOSITEREQUEST._serialized_start=11402
  _STREAMSETUPSTORECOMPOSITEREQUEST._serialized_end=11576
  _STREAMSETUPSTOREARBITRARYAXESREQUEST._serialized_start=11579
  _STREAMSETUPSTOREARBITRARYAXESREQUEST._serialized_end=11717
  _STREAMCALLREQUEST._serialized_start=11719
  _STREAMCALLREQUEST._serialized_end=11818
  _STREAMLINEREQUEST._serialized_start=11821
  _STREAMLINEREQUEST._serialized_end=12069
  _STREAMLINEREQUEST_TYPE._serialized_start=12045
  _STREAMLINEREQUEST_TYPE._serialized_end=12069
  _STREAMARCREQUEST._serialized_start=12072
  _STREAMARCREQUEST._serialized_end=12505
  _STREAMARCREQUEST_TYPE._serialized_start=12045
  _STREAMARCREQUEST_TYPE._serialized_end=12069
  _STREAMCIRCLEREQUEST._serialized_start=12508
  _STREAMCIRCLEREQUEST._serialized_end=12843
  _STREAMCIRCLEREQUEST_TYPE._serialized_start=12045
  _STREAMCIRCLEREQUEST_TYPE._serialized_end=12069
  _STREAMWAITDIGITALINPUTREQUEST._serialized_start=12845
  _STREAMWAITDIGITALINPUTREQUEST._serialized_end=12972
  _STREAMWAITANALOGINPUTREQUEST._serialized_start=12975
  _STREAMWAITANALOGINPUTREQUEST._serialized_end=13120
  _STREAMSETDIGITALOUTPUTREQUEST._serialized_start=13122
  _STREAMSETDIGITALOUTPUTREQUEST._serialized_end=13249
  _STREAMSETANALOGOUTPUTREQUEST._serialized_start=13251
  _STREAMSETANALOGOUTPUTREQUEST._serialized_end=13377
  _STREAMTOGGLEDIGITALOUTPUTREQUEST._serialized_start=13379
  _STREAMTOGGLEDIGITALOUTPUTREQUEST._serialized_end=13494
  _STREAMSETALLDIGITALOUTPUTSREQUEST._serialized_start=13496
  _STREAMSETALLDIGITALOUTPUTSREQUEST._serialized_end=13604
  _STREAMSETALLANALOGOUTPUTSREQUEST._serialized_start=13606
  _STREAMSETALLANALOGOUTPUTSREQUEST._serialized_end=13713
  _STREAMWAITREQUEST._serialized_start=13715
  _STREAMWAITREQUEST._serialized_end=13819
  _STREAMWAITUNTILIDLEREQUEST._serialized_start=13821
  _STREAMWAITUNTILIDLEREQUEST._serialized_end=13936
  _STREAMCORKREQUEST._serialized_start=13938
  _STREAMCORKREQUEST._serialized_end=14014
  _STREAMUNCORKREQUEST._serialized_start=14016
  _STREAMUNCORKREQUEST._serialized_end=14094
  _STREAMISBUSYREQUEST._serialized_start=14096
  _STREAMISBUSYREQUEST._serialized_end=14174
  _STREAMISBUSYRESPONSE._serialized_start=14176
  _STREAMISBUSYRESPONSE._serialized_end=14215
  _STREAMGETAXESREQUEST._serialized_start=14217
  _STREAMGETAXESREQUEST._serialized_end=14296
  _STREAMGETAXESRESPONSE._serialized_start=14298
  _STREAMGETAXESRESPONSE._serialized_end=14381
  _STREAMGETMODEREQUEST._serialized_start=14383
  _STREAMGETMODEREQUEST._serialized_end=14462
  _STREAMGETMODERESPONSE._serialized_start=14464
  _STREAMGETMODERESPONSE._serialized_end=14501
  _STREAMGETMAXSPEEDREQUEST._serialized_start=14503
  _STREAMGETMAXSPEEDREQUEST._serialized_end=14600
  _STREAMGETMAXSPEEDRESPONSE._serialized_start=14602
  _STREAMGETMAXSPEEDRESPONSE._serialized_end=14648
  _STREAMSETMAXSPEEDREQUEST._serialized_start=14650
  _STREAMSETMAXSPEEDREQUEST._serialized_end=14766
  _STREAMGETMAXTANGENTIALACCELERATIONREQUEST._serialized_start=14768
  _STREAMGETMAXTANGENTIALACCELERATIONREQUEST._serialized_end=14882
  _STREAMGETMAXTANGENTIALACCELERATIONRESPONSE._serialized_start=14884
  _STREAMGETMAXTANGENTIALACCELERATIONRESPONSE._serialized_end=14965
  _STREAMSETMAXTANGENTIALACCELERATIONREQUEST._serialized_start=14968
  _STREAMSETMAXTANGENTIALACCELERATIONREQUEST._serialized_end=15119
  _STREAMGETMAXCENTRIPETALACCELERATIONREQUEST._serialized_start=15121
  _STREAMGETMAXCENTRIPETALACCELERATIONREQUEST._serialized_end=15236
  _STREAMGETMAXCENTRIPETALACCELERATIONRESPONSE._serialized_start=15238
  _STREAMGETMAXCENTRIPETALACCELERATIONRESPONSE._serialized_end=15321
  _STREAMSETMAXCENTRIPETALACCELERATIONREQUEST._serialized_start=15324
  _STREAMSETMAXCENTRIPETALACCELERATIONREQUEST._serialized_end=15477
  _STREAMTOSTRINGREQUEST._serialized_start=15479
  _STREAMTOSTRINGREQUEST._serialized_end=15559
  _STREAMTOSTRINGRESPONSE._serialized_start=15561
  _STREAMTOSTRINGRESPONSE._serialized_end=15601
  _STREAMDISABLEREQUEST._serialized_start=15603
  _STREAMDISABLEREQUEST._serialized_end=15682
  _STREAMBUFFERGETCONTENTREQUEST._serialized_start=15684
  _STREAMBUFFERGETCONTENTREQUEST._serialized_end=15772
  _STREAMBUFFERGETCONTENTRESPONSE._serialized_start=15774
  _STREAMBUFFERGETCONTENTRESPONSE._serialized_end=15828
  _STREAMBUFFERERASEREQUEST._serialized_start=15830
  _STREAMBUFFERERASEREQUEST._serialized_end=15913
  _STREAMGENERICCOMMANDREQUEST._serialized_start=15915
  _STREAMGENERICCOMMANDREQUEST._serialized_end=16018
  _STREAMGENERICCOMMANDBATCHREQUEST._serialized_start=16020
  _STREAMGENERICCOMMANDBATCHREQUEST._serialized_end=16126
  _BINARYREPLYONLYEVENT._serialized_start=16128
  _BINARYREPLYONLYEVENT._serialized_end=16227
  _OPENBINARYINTERFACEREQUEST._serialized_start=16230
  _OPENBINARYINTERFACEREQUEST._serialized_end=16417
  _UNKNOWNBINARYRESPONSEEVENT._serialized_start=16419
  _UNKNOWNBINARYRESPONSEEVENT._serialized_end=16524
  _GENERICBINARYREQUEST._serialized_start=16527
  _GENERICBINARYREQUEST._serialized_end=16657
  _BINARYMESSAGE._serialized_start=16659
  _BINARYMESSAGE._serialized_end=16729
  _BINARYMESSAGECOLLECTION._serialized_start=16731
  _BINARYMESSAGECOLLECTION._serialized_end=16813
  _BINARYDEVICERENUMBERREQUEST._serialized_start=16815
  _BINARYDEVICERENUMBERREQUEST._serialized_end=16866
  _BINARYDEVICERENUMBERRESPONSE._serialized_start=16868
  _BINARYDEVICERENUMBERRESPONSE._serialized_end=16922
  _BINARYDEVICEIDENTIFYREQUEST._serialized_start=16924
  _BINARYDEVICEIDENTIFYREQUEST._serialized_end=16991
  _BINARYDEVICEIDENTITY._serialized_start=16994
  _BINARYDEVICEIDENTITY._serialized_end=17339
  _BINARYDEVICEIDENTITY_DEVICETYPE._serialized_start=17290
  _BINARYDEVICEIDENTITY_DEVICETYPE._serialized_end=17339
  _BINARYDEVICEGETIDENTITYREQUEST._serialized_start=17341
  _BINARYDEVICEGETIDENTITYREQUEST._serialized_end=17411
  _BINARYDEVICEGETIDENTITYRESPONSE._serialized_start=17413
  _BINARYDEVICEGETIDENTITYRESPONSE._serialized_end=17510
  _BINARYDEVICEGETISIDENTIFIEDREQUEST._serialized_start=17512
  _BINARYDEVICEGETISIDENTIFIEDREQUEST._serialized_end=17586
  _BINARYDEVICEGETISIDENTIFIEDRESPONSE._serialized_start=17588
  _BINARYDEVICEGETISIDENTIFIEDRESPONSE._serialized_end=17648
  _BINARYGENERICWITHUNITSREQUEST._serialized_start=17651
  _BINARYGENERICWITHUNITSREQUEST._serialized_end=17804
  _BINARYGENERICWITHUNITSRESPONSE._serialized_start=17806
  _BINARYGENERICWITHUNITSRESPONSE._serialized_end=17852
  _BINARYDEVICEHOMEREQUEST._serialized_start=17854
  _BINARYDEVICEHOMEREQUEST._serialized_end=17948
  _BINARYDEVICEMOVEMENTRESPONSE._serialized_start=17950
  _BINARYDEVICEMOVEMENTRESPONSE._serialized_end=17994
  _BINARYDEVICEMOVEREQUEST._serialized_start=17997
  _BINARYDEVICEMOVEREQUEST._serialized_end=18215
  _BINARYDEVICEMOVEREQUEST_MOVETYPE._serialized_start=4859
  _BINARYDEVICEMOVEREQUEST_MOVETYPE._serialized_end=4896
  _BINARYDEVICESTOPREQUEST._serialized_start=18217
  _BINARYDEVICESTOPREQUEST._serialized_end=18311
  _BINARYDEVICEWAITUNTILIDLEREQUEST._serialized_start=18313
  _BINARYDEVICEWAITUNTILIDLEREQUEST._serialized_end=18385
  _BINARYDEVICEISBUSYREQUEST._serialized_start=18387
  _BINARYDEVICEISBUSYREQUEST._serialized_end=18452
  _BINARYDEVICEISBUSYRESPONSE._serialized_start=18454
  _BINARYDEVICEISBUSYRESPONSE._serialized_end=18499
  _BINARYDEVICEDETECTREQUEST._serialized_start=18501
  _BINARYDEVICEDETECTREQUEST._serialized_end=18576
  _BINARYDEVICEDETECTRESPONSE._serialized_start=18578
  _BINARYDEVICEDETECTRESPONSE._serialized_end=18623
  _BINARYDEVICEGETSETTINGREQUEST._serialized_start=18625
  _BINARYDEVICEGETSETTINGREQUEST._serialized_end=18725
  _BINARYDEVICEGETSETTINGRESPONSE._serialized_start=18727
  _BINARYDEVICEGETSETTINGRESPONSE._serialized_end=18774
  _BINARYDEVICESETSETTINGREQUEST._serialized_start=18776
  _BINARYDEVICESETSETTINGREQUEST._serialized_end=18891
  _BINARYDEVICEPARKREQUEST._serialized_start=18893
  _BINARYDEVICEPARKREQUEST._serialized_end=18956
  _BINARYDEVICEPARKRESPONSE._serialized_start=18958
  _BINARYDEVICEPARKRESPONSE._serialized_end=19003
  _CUSTOMINTERFACEREADREQUEST._serialized_start=19005
  _CUSTOMINTERFACEREADREQUEST._serialized_end=19055
  _CUSTOMINTERFACEREADRESPONSE._serialized_start=19057
  _CUSTOMINTERFACEREADRESPONSE._serialized_end=19103
  _CUSTOMINTERFACEWRITEREQUEST._serialized_start=19105
  _CUSTOMINTERFACEWRITEREQUEST._serialized_end=19173
  _CUSTOMINTERFACEOPENRESPONSE._serialized_start=19175
  _CUSTOMINTERFACEOPENRESPONSE._serialized_end=19226
  _CUSTOMINTERFACECLOSEREQUEST._serialized_start=19228
  _CUSTOMINTERFACECLOSEREQUEST._serialized_end=19302
  _GETSTATEREQUEST._serialized_start=19304
  _GETSTATEREQUEST._serialized_end=19373
  _GETSTATERESPONSE._serialized_start=19375
  _GETSTATERESPONSE._serialized_end=19408
  _CANSETSTATEREQUEST._serialized_start=19410
  _CANSETSTATEREQUEST._serialized_end=19518
  _CANSETSTATEAXISRESPONSE._serialized_start=19520
  _CANSETSTATEAXISRESPONSE._serialized_end=19581
  _CANSETSTATEDEVICERESPONSE._serialized_start=19583
  _CANSETSTATEDEVICERESPONSE._serialized_end=19701
  _SETSTATEREQUEST._serialized_start=19703
  _SETSTATEREQUEST._serialized_end=19808
  _SERVOTUNINGREQUEST._serialized_start=19810
  _SERVOTUNINGREQUEST._serialized_end=19900
  _SERVOTUNINGPARAM._serialized_start=19902
  _SERVOTUNINGPARAM._serialized_end=19949
  _PARAMSETINFO._serialized_start=19951
  _PARAMSETINFO._serialized_end=20037
  _SETSERVOTUNINGREQUEST._serialized_start=20040
  _SETSERVOTUNINGREQUEST._serialized_end=20198
  _GETSTARTUPPARAMSET._serialized_start=20200
  _GETSTARTUPPARAMSET._serialized_end=20272
  _STARTUPPARAMSET._serialized_start=20274
  _STARTUPPARAMSET._serialized_end=20309
  _LOADPARAMSET._serialized_start=20311
  _LOADPARAMSET._serialized_end=20421
  _SETSERVOTUNINGPIDREQUEST._serialized_start=20424
  _SETSERVOTUNINGPIDREQUEST._serialized_end=20565
  _PIDTUNING._serialized_start=20567
  _PIDTUNING._serialized_end=20654
  _GETSIMPLETUNINGPARAMLISTREQUEST._serialized_start=20656
  _GETSIMPLETUNINGPARAMLISTREQUEST._serialized_end=20741
  _SETSIMPLETUNING._serialized_start=20744
  _SETSIMPLETUNING._serialized_end=20938
  _SIMPLETUNINGPARAM._serialized_start=20940
  _SIMPLETUNINGPARAM._serialized_end=21030
  _SIMPLETUNINGPARAMLIST._serialized_start=21032
  _SIMPLETUNINGPARAMLIST._serialized_end=21114
  _TRANSLATORCREATEREQUEST._serialized_start=21117
  _TRANSLATORCREATEREQUEST._serialized_end=21266
  _TRANSLATORCREATERESPONSE._serialized_start=21268
  _TRANSLATORCREATERESPONSE._serialized_end=21317
  _TRANSLATORAXISDEFINITION._serialized_start=21319
  _TRANSLATORAXISDEFINITION._serialized_end=21398
  _TRANSLATORDEFINITION._serialized_start=21401
  _TRANSLATORDEFINITION._serialized_end=21562
  _TRANSLATORCONFIG._serialized_start=21565
  _TRANSLATORCONFIG._serialized_end=21737
  _TRANSLATORAXISMAPPING._serialized_start=21739
  _TRANSLATORAXISMAPPING._serialized_end=21803
  _TRANSLATORAXISTRANSFORMATION._serialized_start=21805
  _TRANSLATORAXISTRANSFORMATION._serialized_end=21931
  _TRANSLATORTRANSLATEREQUEST._serialized_start=21933
  _TRANSLATORTRANSLATEREQUEST._serialized_end=21999
  _TRANSLATEMESSAGE._serialized_start=22001
  _TRANSLATEMESSAGE._serialized_end=22074
  _TRANSLATORTRANSLATERESPONSE._serialized_start=22076
  _TRANSLATORTRANSLATERESPONSE._serialized_end=22183
  _GCODESYNTAXEXCEPTIONDATA._serialized_start=22185
  _GCODESYNTAXEXCEPTIONDATA._serialized_end=22249
  _GCODEEXECUTIONEXCEPTIONDATA._serialized_start=22251
  _GCODEEXECUTIONEXCEPTIONDATA._serialized_end=22318
  _TRANSLATORFLUSHLIVEREQUEST._serialized_start=22320
  _TRANSLATORFLUSHLIVEREQUEST._serialized_end=22396
  _TRANSLATORFLUSHRESPONSE._serialized_start=22398
  _TRANSLATORFLUSHRESPONSE._serialized_end=22441
  _TRANSLATORCREATELIVEREQUEST._serialized_start=22444
  _TRANSLATORCREATELIVEREQUEST._serialized_end=22588
  _TRANSLATOREMPTYREQUEST._serialized_start=22590
  _TRANSLATOREMPTYREQUEST._serialized_end=22637
  _TRANSLATORSETTRAVERSERATEREQUEST._serialized_start=22639
  _TRANSLATORSETTRAVERSERATEREQUEST._serialized_end=22733
  _TRANSLATORSETAXISPOSITIONREQUEST._serialized_start=22735
  _TRANSLATORSETAXISPOSITIONREQUEST._serialized_end=22838
  _TRANSLATORGETAXISPOSITIONREQUEST._serialized_start=22840
  _TRANSLATORGETAXISPOSITIONREQUEST._serialized_end=22925
  _TRANSLATORGETAXISPOSITIONRESPONSE._serialized_start=22927
  _TRANSLATORGETAXISPOSITIONRESPONSE._serialized_end=22977
  _TRANSLATORGETAXISOFFSETREQUEST._serialized_start=22979
  _TRANSLATORGETAXISOFFSETREQUEST._serialized_end=23089
  _TRANSLATORGETCURRENTCOORDINATESYSTEMRESPONSE._serialized_start=23091
  _TRANSLATORGETCURRENTCOORDINATESYSTEMRESPONSE._serialized_end=23152
  _TRANSLATORSETFEEDRATEOVERRIDEREQUEST._serialized_start=23154
  _TRANSLATORSETFEEDRATEOVERRIDEREQUEST._serialized_end=23236
# @@protoc_insertion_point(module_scope)
